DROP TABLE IF EXISTS `appscheduler_bookings`;
CREATE TABLE IF NOT EXISTS `appscheduler_bookings` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `uuid` varchar(12) DEFAULT NULL,
  `calendar_id` int(10) unsigned DEFAULT NULL,
  `booking_price` decimal(9,2) unsigned DEFAULT NULL,
  `booking_total` decimal(9,2) unsigned DEFAULT NULL,
  `booking_deposit` decimal(9,2) unsigned DEFAULT NULL,
  `booking_tax` decimal(9,2) unsigned DEFAULT NULL,
  `booking_status` enum('pending','confirmed','cancelled') DEFAULT NULL,
  `payment_method` enum('paypal','authorize','creditcard','bank') DEFAULT NULL,
  `c_name` varchar(255) DEFAULT NULL,
  `c_email` varchar(255) DEFAULT NULL,
  `c_phone` varchar(255) DEFAULT NULL,
  `c_country_id` int(10) unsigned DEFAULT NULL,
  `c_city` varchar(255) DEFAULT NULL,
  `c_state` varchar(255) DEFAULT NULL,
  `c_zip` varchar(255) DEFAULT NULL,
  `c_address_1` varchar(255) DEFAULT NULL,
  `c_address_2` varchar(255) DEFAULT NULL,
  `c_notes` text,
  `cc_type` varchar(255) DEFAULT NULL,
  `cc_num` varchar(255) DEFAULT NULL,
  `cc_exp_year` year(4) DEFAULT NULL,
  `cc_exp_month` varchar(2) DEFAULT NULL,
  `cc_code` varchar(255) DEFAULT NULL,
  `txn_id` varchar(255) DEFAULT NULL,
  `processed_on` datetime DEFAULT NULL,
  `created` datetime DEFAULT NULL,
  `locale_id` tinyint(3) unsigned DEFAULT NULL,
  `ip` varchar(15) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uuid` (`uuid`),
  KEY `calendar_id` (`calendar_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `appscheduler_bookings_services`;
CREATE TABLE IF NOT EXISTS `appscheduler_bookings_services` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `tmp_hash` varchar(32) DEFAULT NULL,
  `booking_id` int(10) unsigned DEFAULT NULL,
  `service_id` int(10) unsigned DEFAULT NULL,
  `employee_id` int(10) unsigned DEFAULT NULL,
  `date` date DEFAULT NULL,
  `start` time DEFAULT NULL,
  `start_ts` int(10) unsigned DEFAULT NULL,
  `total` smallint(5) unsigned DEFAULT NULL,
  `price` decimal(9,2) unsigned DEFAULT NULL,
  `reminder_email` tinyint(1) unsigned DEFAULT '0',
  `reminder_sms` tinyint(1) unsigned DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `booking_id` (`booking_id`),
  KEY `tmp_hash` (`tmp_hash`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `appscheduler_calendars`;
CREATE TABLE IF NOT EXISTS `appscheduler_calendars` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `user_id` (`user_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `appscheduler_dates`;
CREATE TABLE IF NOT EXISTS `appscheduler_dates` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `foreign_id` int(10) unsigned DEFAULT NULL,
  `type` enum('calendar','employee') DEFAULT NULL,
  `date` date NOT NULL DEFAULT '0000-00-00',
  `start_time` time DEFAULT NULL,
  `end_time` time DEFAULT NULL,
  `start_lunch` time DEFAULT NULL,
  `end_lunch` time DEFAULT NULL,
  `is_dayoff` enum('T','F') DEFAULT 'F',
  PRIMARY KEY (`id`),
  UNIQUE KEY `foreign_id` (`foreign_id`,`type`,`date`),
  KEY `is_dayoff` (`is_dayoff`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `appscheduler_employees`;
CREATE TABLE IF NOT EXISTS `appscheduler_employees` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `calendar_id` int(10) unsigned DEFAULT NULL,
  `email` varchar(255) DEFAULT NULL,
  `password` blob,
  `phone` varchar(255) DEFAULT NULL,
  `notes` text,
  `avatar` varchar(255) DEFAULT NULL,
  `last_login` datetime DEFAULT NULL,
  `is_subscribed` tinyint(1) unsigned DEFAULT '0',
  `is_subscribed_sms` tinyint(1) unsigned DEFAULT '0',
  `is_active` tinyint(1) unsigned DEFAULT '1',
  PRIMARY KEY (`id`),
  UNIQUE KEY `email` (`email`),
  KEY `calendar_id` (`calendar_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `appscheduler_employees_services`;
CREATE TABLE IF NOT EXISTS `appscheduler_employees_services` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `employee_id` int(10) unsigned NOT NULL,
  `service_id` int(10) unsigned NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `employee_id` (`employee_id`,`service_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `appscheduler_fields`;
CREATE TABLE IF NOT EXISTS `appscheduler_fields` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `key` varchar(100) DEFAULT NULL,
  `type` enum('backend','frontend','arrays') DEFAULT NULL,
  `label` varchar(255) DEFAULT NULL,
  `source` enum('script','plugin') DEFAULT 'script',
  `modified` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `key` (`key`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `appscheduler_multi_lang`;
CREATE TABLE IF NOT EXISTS `appscheduler_multi_lang` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `foreign_id` int(10) unsigned DEFAULT NULL,
  `model` varchar(50) DEFAULT NULL,
  `locale` tinyint(3) unsigned DEFAULT NULL,
  `field` varchar(50) DEFAULT NULL,
  `content` text,
  `source` enum('script','plugin','data') DEFAULT 'script',
  PRIMARY KEY (`id`),
  UNIQUE KEY `foreign_id` (`foreign_id`,`model`,`locale`,`field`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `appscheduler_options`;
CREATE TABLE IF NOT EXISTS `appscheduler_options` (
  `foreign_id` int(10) unsigned NOT NULL DEFAULT '0',
  `key` varchar(255) NOT NULL DEFAULT '',
  `tab_id` tinyint(3) unsigned DEFAULT NULL,
  `value` text,
  `label` text,
  `type` enum('string','text','int','float','enum','bool') NOT NULL DEFAULT 'string',
  `order` int(10) unsigned DEFAULT NULL,
  `is_visible` tinyint(1) unsigned DEFAULT '1',
  `style` varchar(500) DEFAULT NULL,
  PRIMARY KEY (`foreign_id`,`key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `appscheduler_roles`;
CREATE TABLE IF NOT EXISTS `appscheduler_roles` (
  `id` tinyint(3) unsigned NOT NULL AUTO_INCREMENT,
  `role` varchar(255) DEFAULT NULL,
  `status` enum('T','F') NOT NULL DEFAULT 'T',
  PRIMARY KEY (`id`),
  KEY `status` (`status`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `appscheduler_services`;
CREATE TABLE IF NOT EXISTS `appscheduler_services` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `calendar_id` int(10) unsigned DEFAULT NULL,
  `price` decimal(9,2) unsigned DEFAULT NULL,
  `length` smallint(5) unsigned DEFAULT NULL,
  `before` smallint(5) unsigned DEFAULT NULL,
  `after` smallint(5) unsigned DEFAULT NULL,
  `total` smallint(5) unsigned DEFAULT NULL,
  `is_active` tinyint(1) unsigned DEFAULT '1',
  PRIMARY KEY (`id`),
  KEY `calendar_id` (`calendar_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `appscheduler_users`;
CREATE TABLE IF NOT EXISTS `appscheduler_users` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `role_id` int(10) unsigned NOT NULL,
  `email` varchar(255) DEFAULT NULL,
  `password` blob,
  `name` varchar(255) DEFAULT NULL,
  `phone` varchar(255) DEFAULT NULL,
  `created` datetime NOT NULL,
  `last_login` datetime DEFAULT NULL,
  `status` enum('T','F') NOT NULL DEFAULT 'T',
  `ip` varchar(15) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `email` (`email`),
  KEY `role_id` (`role_id`),
  KEY `status` (`status`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `appscheduler_working_times`;
CREATE TABLE IF NOT EXISTS `appscheduler_working_times` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `foreign_id` int(10) unsigned DEFAULT NULL,
  `type` enum('calendar','employee') DEFAULT NULL,
  `monday_from` time DEFAULT NULL,
  `monday_to` time DEFAULT NULL,
  `monday_lunch_from` time DEFAULT NULL,
  `monday_lunch_to` time DEFAULT NULL,
  `monday_dayoff` enum('T','F') DEFAULT 'F',
  `tuesday_from` time DEFAULT NULL,
  `tuesday_to` time DEFAULT NULL,
  `tuesday_lunch_from` time DEFAULT NULL,
  `tuesday_lunch_to` time DEFAULT NULL,
  `tuesday_dayoff` enum('T','F') DEFAULT 'F',
  `wednesday_from` time DEFAULT NULL,
  `wednesday_to` time DEFAULT NULL,
  `wednesday_lunch_from` time DEFAULT NULL,
  `wednesday_lunch_to` time DEFAULT NULL,
  `wednesday_dayoff` enum('T','F') DEFAULT 'F',
  `thursday_from` time DEFAULT NULL,
  `thursday_to` time DEFAULT NULL,
  `thursday_lunch_from` time DEFAULT NULL,
  `thursday_lunch_to` time DEFAULT NULL,
  `thursday_dayoff` enum('T','F') DEFAULT 'F',
  `friday_from` time DEFAULT NULL,
  `friday_to` time DEFAULT NULL,
  `friday_lunch_from` time DEFAULT NULL,
  `friday_lunch_to` time DEFAULT NULL,
  `friday_dayoff` enum('T','F') DEFAULT 'F',
  `saturday_from` time DEFAULT NULL,
  `saturday_to` time DEFAULT NULL,
  `saturday_lunch_from` time DEFAULT NULL,
  `saturday_lunch_to` time DEFAULT NULL,
  `saturday_dayoff` enum('T','F') DEFAULT 'F',
  `sunday_from` time DEFAULT NULL,
  `sunday_to` time DEFAULT NULL,
  `sunday_lunch_from` time DEFAULT NULL,
  `sunday_lunch_to` time DEFAULT NULL,
  `sunday_dayoff` enum('T','F') DEFAULT 'F',
  PRIMARY KEY (`id`),
  UNIQUE KEY `foreign_id` (`foreign_id`,`type`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

INSERT INTO `appscheduler_roles` (`id`, `role`, `status`) VALUES
(1, 'admin', 'T');

INSERT INTO `appscheduler_calendars` (`id`, `user_id`) VALUES
(1, 1);

INSERT INTO `appscheduler_working_times` (`id`, `foreign_id`, `type`, `monday_from`, `monday_to`, `monday_lunch_from`, `monday_lunch_to`, `monday_dayoff`, `tuesday_from`, `tuesday_to`, `tuesday_lunch_from`, `tuesday_lunch_to`, `tuesday_dayoff`, `wednesday_from`, `wednesday_to`, `wednesday_lunch_from`, `wednesday_lunch_to`, `wednesday_dayoff`, `thursday_from`, `thursday_to`, `thursday_lunch_from`, `thursday_lunch_to`, `thursday_dayoff`, `friday_from`, `friday_to`, `friday_lunch_from`, `friday_lunch_to`, `friday_dayoff`, `saturday_from`, `saturday_to`, `saturday_lunch_from`, `saturday_lunch_to`, `saturday_dayoff`, `sunday_from`, `sunday_to`, `sunday_lunch_from`, `sunday_lunch_to`, `sunday_dayoff`) VALUES
(1, 1, 'calendar', '09:30:00', '18:30:00', '12:30:00', '13:30:00', 'F', '09:00:00', '18:00:00', '12:30:00', '13:30:00', 'F', '09:45:00', '17:30:00', '11:00:00', '12:00:00', 'F', '09:00:00', '18:00:00', '12:30:00', '13:30:00', 'F', '09:00:00', '18:00:00', '12:30:00', '13:30:00', 'F', NULL, NULL, NULL, NULL, 'T', NULL, NULL, NULL, NULL, 'T');

INSERT INTO `appscheduler_options` (`foreign_id`, `key`, `tab_id`, `value`, `label`, `type`, `order`, `is_visible`, `style`) VALUES
(1, 'o_accept_bookings', 3, '1|0::1', NULL, 'bool', 1, 1, NULL),
(1, 'o_allow_authorize', 7, '1|0::1', NULL, 'bool', 18, 1, NULL),
(1, 'o_allow_bank', 7, '1|0::1', NULL, 'bool', 24, 1, NULL),
(1, 'o_allow_creditcard', 7, '1|0::1', NULL, 'bool', 23, 1, NULL),
(1, 'o_allow_paypal', 7, '1|0::1', NULL, 'bool', 16, 1, NULL),
(1, 'o_authorize_hash', 7, 'abcd', NULL, 'string', 21, 1, NULL),
(1, 'o_authorize_key', 7, '53N2U726wZwksK4a', NULL, 'string', 20, 1, NULL),
(1, 'o_authorize_mid', 7, '745ean5JCt2Y', NULL, 'string', 19, 1, NULL),
(1, 'o_authorize_tz', 7, '-43200|-39600|-36000|-32400|-28800|-25200|-21600|-18000|-14400|-10800|-7200|-3600|0|3600|7200|10800|14400|18000|21600|25200|28800|32400|36000|39600|43200|46800::0', 'GMT-12:00|GMT-11:00|GMT-10:00|GMT-09:00|GMT-08:00|GMT-07:00|GMT-06:00|GMT-05:00|GMT-04:00|GMT-03:00|GMT-02:00|GMT-01:00|GMT|GMT+01:00|GMT+02:00|GMT+03:00|GMT+04:00|GMT+05:00|GMT+06:00|GMT+07:00|GMT+08:00|GMT+09:00|GMT+10:00|GMT+11:00|GMT+12:00|GMT+13:00', 'enum', 22, 1, NULL),
(1, 'o_bank_account', 7, 'Bank of America', NULL, 'text', 25, 1, NULL),
(1, 'o_bf_address_1', 4, '1|2|3::2', 'No|Yes|Yes (Required)', 'enum', 6, 1, NULL),
(1, 'o_bf_address_2', 4, '1|2|3::3', 'No|Yes|Yes (Required)', 'enum', 7, 1, NULL),
(1, 'o_bf_captcha', 4, '1|3::3', 'No|Yes (Required)', 'enum', 16, 1, NULL),
(1, 'o_bf_city', 4, '1|2|3::2', 'No|Yes|Yes (Required)', 'enum', 12, 1, NULL),
(1, 'o_bf_country', 4, '1|2|3::3', 'No|Yes|Yes (Required)', 'enum', 15, 1, NULL),
(1, 'o_bf_email', 4, '1|2|3::3', 'No|Yes|Yes (Required)', 'enum', 4, 1, NULL),
(1, 'o_bf_name', 4, '1|2|3::3', 'No|Yes|Yes (Required)', 'enum', 3, 1, NULL),
(1, 'o_bf_notes', 4, '1|2|3::3', 'No|Yes|Yes (Required)', 'enum', 8, 1, NULL),
(1, 'o_bf_phone', 4, '1|2|3::3', 'No|Yes|Yes (Required)', 'enum', 5, 1, NULL),
(1, 'o_bf_state', 4, '1|2|3::2', 'No|Yes|Yes (Required)', 'enum', 13, 1, NULL),
(1, 'o_bf_terms', 4, '1|3::3', 'No|Yes (Required)', 'enum', 17, 1, NULL),
(1, 'o_bf_zip', 4, '1|2|3::2', 'No|Yes|Yes (Required)', 'enum', 14, 1, NULL),
(1, 'o_currency', 1, 'AED|AFN|ALL|AMD|ANG|AOA|ARS|AUD|AWG|AZN|BAM|BBD|BDT|BGN|BHD|BIF|BMD|BND|BOB|BOV|BRL|BSD|BTN|BWP|BYR|BZD|CAD|CDF|CHE|CHF|CHW|CLF|CLP|CNY|COP|COU|CRC|CUC|CUP|CVE|CZK|DJF|DKK|DOP|DZD|EEK|EGP|ERN|ETB|EUR|FJD|FKP|GBP|GEL|GHS|GIP|GMD|GNF|GTQ|GYD|HKD|HNL|HRK|HTG|HUF|IDR|ILS|INR|IQD|IRR|ISK|JMD|JOD|JPY|KES|KGS|KHR|KMF|KPW|KRW|KWD|KYD|KZT|LAK|LBP|LKR|LRD|LSL|LTL|LVL|LYD|MAD|MDL|MGA|MKD|MMK|MNT|MOP|MRO|MUR|MVR|MWK|MXN|MXV|MYR|MZN|NAD|NGN|NIO|NOK|NPR|NZD|OMR|PAB|PEN|PGK|PHP|PKR|PLN|PYG|QAR|RON|RSD|RUB|RWF|SAR|SBD|SCR|SDG|SEK|SGD|SHP|SLL|SOS|SRD|STD|SYP|SZL|THB|TJS|TMT|TND|TOP|TRY|TTD|TWD|TZS|UAH|UGX|USD|USN|USS|UYU|UZS|VEF|VND|VUV|WST|XAF|XAG|XAU|XBA|XBB|XBC|XBD|XCD|XDR|XFU|XOF|XPD|XPF|XPT|XTS|XXX|YER|ZAR|ZMK|ZWL::EUR', NULL, 'enum', 3, 1, NULL),
(1, 'o_datetime_format', 1, 'd.m.Y, H:i|d.m.Y, H:i:s|m.d.Y, H:i|m.d.Y, H:i:s|Y.m.d, H:i|Y.m.d, H:i:s|j.n.Y, H:i|j.n.Y, H:i:s|n.j.Y, H:i|n.j.Y, H:i:s|Y.n.j, H:i|Y.n.j, H:i:s|d/m/Y, H:i|d/m/Y, H:i:s|m/d/Y, H:i|m/d/Y, H:i:s|Y/m/d, H:i|Y/m/d, H:i:s|j/n/Y, H:i|j/n/Y, H:i:s|n/j/Y, H:i|n/j/Y, H:i:s|Y/n/j, H:i|Y/n/j, H:i:s|d-m-Y, H:i|d-m-Y, H:i:s|m-d-Y, H:i|m-d-Y, H:i:s|Y-m-d, H:i|Y-m-d, H:i:s|j-n-Y, H:i|j-n-Y, H:i:s|n-j-Y, H:i|n-j-Y, H:i:s|Y-n-j, H:i|Y-n-j, H:i:s::j/n/Y, H:i', 'd.m.Y, H:i (25.09.2010, 09:51)|d.m.Y, H:i:s (25.09.2010, 09:51:47)|m.d.Y, H:i (09.25.2010, 09:51)|m.d.Y, H:i:s (09.25.2010, 09:51:47)|Y.m.d, H:i (2010.09.25, 09:51)|Y.m.d, H:i:s (2010.09.25, 09:51:47)|j.n.Y, H:i (25.9.2010, 09:51)|j.n.Y, H:i:s (25.9.2010, 09:51:47)|n.j.Y, H:i (9.25.2010, 09:51)|n.j.Y, H:i:s (9.25.2010, 09:51:47)|Y.n.j, H:i (2010.9.25, 09:51)|Y.n.j, H:i:s (2010.9.25, 09:51:47)|d/m/Y, H:i (25/09/2010, 09:51)|d/m/Y, H:i:s (25/09/2010, 09:51:47)|m/d/Y, H:i (09/25/2010, 09:51)|m/d/Y, H:i:s (09/25/2010, 09:51:47)|Y/m/d, H:i (2010/09/25, 09:51)|Y/m/d, H:i:s (2010/09/25, 09:51:47)|j/n/Y, H:i (25/9/2010, 09:51)|j/n/Y, H:i:s (25/9/2010, 09:51:47)|n/j/Y, H:i (9/25/2010, 09:51)|n/j/Y, H:i:s (9/25/2010, 09:51:47)|Y/n/j, H:i (2010/9/25, 09:51)|Y/n/j, H:i:s (2010/9/25, 09:51:47)|d-m-Y, H:i (25-09-2010, 09:51)|d-m-Y, H:i:s (25-09-2010, 09:51:47)|m-d-Y, H:i (09-25-2010, 09:51)|m-d-Y, H:i:s (09-25-2010, 09:51:47)|Y-m-d, H:i (2010-09-25, 09:51)|Y-m-d, H:i:s (2010-09-25, 09:51:47)|j-n-Y, H:i (25-9-2010, 09:51)|j-n-Y, H:i:s (25-9-2010, 09:51:47)|n-j-Y, H:i (9-25-2010, 09:51)|n-j-Y, H:i:s (9-25-2010, 09:51:47)|Y-n-j, H:i (2010-9-25, 09:51)|Y-n-j, H:i:s (2010-9-25, 09:51:47)', 'enum', 8, 1, NULL),
(1, 'o_date_format', 1, 'd.m.Y|m.d.Y|Y.m.d|j.n.Y|n.j.Y|Y.n.j|d/m/Y|m/d/Y|Y/m/d|j/n/Y|n/j/Y|Y/n/j|d-m-Y|m-d-Y|Y-m-d|j-n-Y|n-j-Y|Y-n-j::d-m-Y', 'd.m.Y (25.09.2012)|m.d.Y (09.25.2012)|Y.m.d (2012.09.25)|j.n.Y (25.9.2012)|n.j.Y (9.25.2012)|Y.n.j (2012.9.25)|d/m/Y (25/09/2012)|m/d/Y (09/25/2012)|Y/m/d (2012/09/25)|j/n/Y (25/9/2012)|n/j/Y (9/25/2012)|Y/n/j (2012/9/25)|d-m-Y (25-09-2012)|m-d-Y (09-25-2012)|Y-m-d (2012-09-25)|j-n-Y (25-9-2012)|n-j-Y (9-25-2012)|Y-n-j (2012-9-25)', 'enum', 6, 1, NULL),
(1, 'o_deposit', 7, '20', NULL, 'float', 12, 1, NULL),
(1, 'o_deposit_type', 7, 'amount|percent::percent', 'Amount|Percent', 'enum', NULL, 0, NULL),
(1, 'o_disable_payments', 7, '1|0::0', NULL, 'bool', 4, 1, NULL),
(1, 'o_hide_prices', 3, '1|0::0', NULL, 'bool', 2, 1, NULL),
(1, 'o_layout', 1, '1|2::1', 'Layout 1|Layout 2', 'enum', 1, 1, NULL),
(1, 'o_multi_lang', 99, '1|0::0', NULL, 'enum', NULL, 0, NULL),
(1, 'o_paypal_address', 7, 'paypal_seller@example.com', NULL, 'string', 17, 1, NULL),
(1, 'o_reminder_body', 8, 'Dear {Name},\\r\\n\\r\\nYour booking is coming soon!\\r\\n\\r\\nBooking ID: {BookingID}\\r\\n\\r\\nServices\\r\\n{Services}\\r\\n\\r\\nRegards,\\r\\nThe Management', NULL, 'text', 4, 1, 'height:350px'),
(1, 'o_reminder_email_before', 8, '10', NULL, 'int', 2, 1, NULL),
(1, 'o_reminder_enable', 8, '1|0::1', NULL, 'bool', 1, 1, NULL),
(1, 'o_reminder_sms_hours', 8, '2', NULL, 'int', 5, 1, NULL),
(1, 'o_reminder_sms_message', 8, '{Name}, your booking is coming.', NULL, 'text', 7, 1, 'height:200px'),
(1, 'o_reminder_subject', 8, 'Booking Reminder', NULL, 'string', 3, 1, NULL),
(1, 'o_send_email', 1, 'mail|smtp::mail', 'PHP mail()|SMTP', 'enum', 11, 1, NULL),
(1, 'o_seo_url', 1, '1|0::1', NULL, 'bool', 20, 1, NULL),
(1, 'o_smtp_host', 1, NULL, NULL, 'string', 12, 1, NULL),
(1, 'o_smtp_pass', 1, NULL, NULL, 'string', 15, 1, NULL),
(1, 'o_smtp_port', 1, '25', NULL, 'int', 13, 1, NULL),
(1, 'o_smtp_user', 1, NULL, NULL, 'string', 14, 1, NULL),
(1, 'o_status_if_not_paid', 3, 'confirmed|pending::pending', 'Confirmed|Pending', 'enum', 10, 1, NULL),
(1, 'o_status_if_paid', 3, 'confirmed|pending::confirmed', 'Confirmed|Pending', 'enum', 9, 1, NULL),
(1, 'o_step', 3, '5|10|15|20|25|30|35|40|45|50|55|60::30', NULL, 'enum', 3, 1, NULL),
(1, 'o_tax', 7, '10', NULL, 'float', 14, 1, NULL),
(1, 'o_thankyou_page', 7, 'http://www.phpjabbers.com/', NULL, 'string', 26, 1, NULL),
(1, 'o_timezone', 1, '-43200|-39600|-36000|-32400|-28800|-25200|-21600|-18000|-14400|-10800|-7200|-3600|0|3600|7200|10800|14400|18000|21600|25200|28800|32400|36000|39600|43200|46800::0', 'GMT-12:00|GMT-11:00|GMT-10:00|GMT-09:00|GMT-08:00|GMT-07:00|GMT-06:00|GMT-05:00|GMT-04:00|GMT-03:00|GMT-02:00|GMT-01:00|GMT|GMT+01:00|GMT+02:00|GMT+03:00|GMT+04:00|GMT+05:00|GMT+06:00|GMT+07:00|GMT+08:00|GMT+09:00|GMT+10:00|GMT+11:00|GMT+12:00|GMT+13:00', 'enum', 10, 1, NULL),
(1, 'o_time_format', 1, 'H:i|G:i|h:i|h:i a|h:i A|g:i|g:i a|g:i A::h:i A', 'H:i (09:45)|G:i (9:45)|h:i (09:45)|h:i a (09:45 am)|h:i A (09:45 AM)|g:i (9:45)|g:i a (9:45 am)|g:i A (9:45 AM)', 'enum', 7, 1, NULL),
(1, 'o_week_numbers', 1, '1|0::1', NULL, 'bool', 19, 1, NULL),
(1, 'o_week_start', 1, '0|1|2|3|4|5|6::1', 'Sunday|Monday|Tuesday|Wednesday|Thursday|Friday|Saturday', 'enum', 9, 1, NULL);
















INSERT INTO `appscheduler_fields` VALUES
('5', 'user', 'backend', 'Username', 'script', NULL),
('6', 'pass', 'backend', 'Password', 'script', NULL),
('7', 'email', 'backend', 'E-Mail', 'script', NULL),
('8', 'url', 'backend', 'URL', 'script', NULL),
('13', 'created', 'backend', 'Created', 'script', NULL),
('16', 'btnSave', 'backend', 'Save', 'script', NULL),
('17', 'btnReset', 'backend', 'Reset', 'script', NULL),
('18', 'addLocale', 'backend', 'Add language', 'script', NULL),
('22', 'menuLang', 'backend', 'Menu Multi lang', 'script', NULL),
('23', 'menuPlugins', 'backend', 'Menu Plugins', 'script', NULL),
('24', 'menuUsers', 'backend', 'Menu Users', 'script', NULL),
('25', 'menuOptions', 'backend', 'Menu Options', 'script', NULL),
('26', 'menuLogout', 'backend', 'Menu Logout', 'script', NULL),
('31', 'btnUpdate', 'backend', 'Update', 'script', NULL),
('36', 'lblChoose', 'backend', 'Choose', 'script', NULL),
('37', 'btnSearch', 'backend', 'Search', 'script', NULL),
('40', 'backend', 'backend', 'Backend titles', 'script', NULL),
('41', 'frontend', 'backend', 'Front-end titles', 'script', NULL),
('42', 'locales', 'backend', 'Languages', 'script', NULL),
('44', 'adminLogin', 'backend', 'Admin Login', 'script', NULL),
('45', 'btnLogin', 'backend', 'Login', 'script', NULL),
('47', 'menuDashboard', 'backend', 'Menu Dashboard', 'script', NULL),
('57', 'lblOptionList', 'backend', 'Option list', 'script', NULL),
('58', 'btnAdd', 'backend', 'Button Add', 'script', NULL),
('62', 'lblDelete', 'backend', 'Delete', 'script', NULL),
('65', 'lblType', 'backend', 'Type', 'script', NULL),
('66', 'lblName', 'backend', 'Name', 'script', NULL),
('67', 'lblRole', 'backend', 'Role', 'script', NULL),
('68', 'lblStatus', 'backend', 'Status', 'script', NULL),
('69', 'lblIsActive', 'backend', 'Is Active', 'script', NULL),
('70', 'lblUpdateUser', 'backend', 'Update user', 'script', NULL),
('71', 'lblAddUser', 'backend', 'Add user', 'script', NULL),
('72', 'lblValue', 'backend', 'Value', 'script', NULL),
('73', 'lblOption', 'backend', 'Option', 'script', NULL),
('74', 'lblDays', 'backend', 'Days', 'script', NULL),
('115', 'menuLocales', 'backend', 'Menu Languages', 'script', NULL),
('116', 'lblYes', 'backend', 'Yes', 'script', NULL),
('117', 'lblNo', 'backend', 'No', 'script', NULL),
('338', 'lblError', 'backend', 'Error', 'script', NULL),
('347', 'btnBack', 'backend', 'Button Back', 'script', NULL),
('355', 'btnCancel', 'backend', 'Button Cancel', 'script', NULL),
('356', 'lblForgot', 'backend', 'Forgot password', 'script', NULL),
('357', 'adminForgot', 'backend', 'Forgot password', 'script', NULL),
('358', 'btnSend', 'backend', 'Button Send', 'script', NULL),
('359', 'emailForgotSubject', 'backend', 'Email / Forgot Subject', 'script', NULL),
('360', 'emailForgotBody', 'backend', 'Email / Forgot Body', 'script', NULL),
('365', 'menuProfile', 'backend', 'Menu Profile', 'script', NULL),
('380', 'infoLocalesTitle', 'backend', 'Infobox / Locales Title', 'script', NULL),
('381', 'infoLocalesBody', 'backend', 'Infobox / Locales Body', 'script', NULL),
('382', 'infoLocalesBackendTitle', 'backend', 'Infobox / Locales Backend Title', 'script', NULL),
('383', 'infoLocalesBackendBody', 'backend', 'Infobox / Locales Backend Body', 'script', NULL),
('384', 'infoLocalesFrontendTitle', 'backend', 'Infobox / Locales Frontend Title', 'script', NULL),
('385', 'infoLocalesFrontendBody', 'backend', 'Infobox / Locales Frontend Body', 'script', NULL),
('386', 'infoListingPricesTitle', 'backend', 'Infobox / Listing Prices Title', 'script', NULL),
('387', 'infoListingPricesBody', 'backend', 'Infobox / Listing Prices Body', 'script', NULL),
('388', 'infoListingBookingsTitle', 'backend', 'Infobox / Listing Bookings Title', 'script', NULL),
('389', 'infoListingBookingsBody', 'backend', 'Infobox / Listing Bookings Body', 'script', NULL),
('390', 'infoListingContactTitle', 'backend', 'Infobox / Listing Contact Title', 'script', NULL),
('391', 'infoListingContactBody', 'backend', 'Infobox / Listing Contact Body', 'script', NULL),
('392', 'infoListingAddressTitle', 'backend', 'Infobox / Listing Address Title', 'script', NULL),
('393', 'infoListingAddressBody', 'backend', 'Infobox / Listing Address Body', 'script', NULL),
('395', 'infoListingExtendTitle', 'backend', 'Infobox / Extend exp.date Title', 'script', NULL),
('396', 'infoListingExtendBody', 'backend', 'Infobox / Extend exp.date Body', 'script', NULL),
('408', 'menuBackup', 'backend', 'Menu Backup', 'script', NULL),
('409', 'btnBackup', 'backend', 'Button Backup', 'script', NULL),
('410', 'lblBackupDatabase', 'backend', 'Backup / Database', 'script', NULL),
('411', 'lblBackupFiles', 'backend', 'Backup / Files', 'script', NULL),
('412', 'gridChooseAction', 'backend', 'Grid / Choose Action', 'script', NULL),
('413', 'gridGotoPage', 'backend', 'Grid / Go to page', 'script', NULL),
('414', 'gridTotalItems', 'backend', 'Grid / Total items', 'script', NULL),
('415', 'gridItemsPerPage', 'backend', 'Grid / Items per page', 'script', NULL),
('416', 'gridPrevPage', 'backend', 'Grid / Prev page', 'script', NULL),
('417', 'gridPrev', 'backend', 'Grid / Prev', 'script', NULL),
('418', 'gridNextPage', 'backend', 'Grid / Next page', 'script', NULL),
('419', 'gridNext', 'backend', 'Grid / Next', 'script', NULL),
('420', 'gridDeleteConfirmation', 'backend', 'Grid / Delete confirmation', 'script', NULL),
('421', 'gridConfirmationTitle', 'backend', 'Grid / Confirmation Title', 'script', NULL),
('422', 'gridActionTitle', 'backend', 'Grid / Action Title', 'script', NULL),
('423', 'gridBtnOk', 'backend', 'Grid / Button OK', 'script', NULL),
('424', 'gridBtnCancel', 'backend', 'Grid / Button Cancel', 'script', NULL),
('425', 'gridBtnDelete', 'backend', 'Grid / Button Delete', 'script', NULL),
('426', 'gridEmptyResult', 'backend', 'Grid / Empty resultset', 'script', NULL),
('433', 'multilangTooltip', 'backend', 'MultiLang / Tooltip', 'script', NULL),
('434', 'lblIp', 'backend', 'IP address', 'script', NULL),
('435', 'lblUserCreated', 'backend', 'User / Registration Date & Time', 'script', NULL),
('441', 'opt_o_currency', 'backend', 'Options / Currency', 'script', NULL),
('442', 'opt_o_date_format', 'backend', 'Options / Date format', 'script', NULL),
('451', 'opt_o_timezone', 'backend', 'Options / Timezone', 'script', NULL),
('452', 'opt_o_week_start', 'backend', 'Options / First day of the week', 'script', NULL),
('455', 'u_statarr_ARRAY_T', 'arrays', 'u_statarr_ARRAY_T', 'script', NULL),
('456', 'u_statarr_ARRAY_F', 'arrays', 'u_statarr_ARRAY_F', 'script', NULL),
('457', 'filter_ARRAY_active', 'arrays', 'filter_ARRAY_active', 'script', NULL),
('458', 'filter_ARRAY_inactive', 'arrays', 'filter_ARRAY_inactive', 'script', NULL),
('471', '_yesno_ARRAY_T', 'arrays', '_yesno_ARRAY_T', 'script', NULL),
('472', '_yesno_ARRAY_F', 'arrays', '_yesno_ARRAY_F', 'script', NULL),
('476', 'personal_titles_ARRAY_mr', 'arrays', 'personal_titles_ARRAY_mr', 'script', NULL),
('477', 'personal_titles_ARRAY_mrs', 'arrays', 'personal_titles_ARRAY_mrs', 'script', NULL),
('478', 'personal_titles_ARRAY_miss', 'arrays', 'personal_titles_ARRAY_miss', 'script', NULL),
('479', 'personal_titles_ARRAY_ms', 'arrays', 'personal_titles_ARRAY_ms', 'script', NULL),
('480', 'personal_titles_ARRAY_dr', 'arrays', 'personal_titles_ARRAY_dr', 'script', NULL),
('481', 'personal_titles_ARRAY_prof', 'arrays', 'personal_titles_ARRAY_prof', 'script', NULL),
('482', 'personal_titles_ARRAY_rev', 'arrays', 'personal_titles_ARRAY_rev', 'script', NULL),
('483', 'personal_titles_ARRAY_other', 'arrays', 'personal_titles_ARRAY_other', 'script', NULL),
('496', 'timezones_ARRAY_-43200', 'arrays', 'timezones_ARRAY_-43200', 'script', NULL),
('497', 'timezones_ARRAY_-39600', 'arrays', 'timezones_ARRAY_-39600', 'script', NULL),
('498', 'timezones_ARRAY_-36000', 'arrays', 'timezones_ARRAY_-36000', 'script', NULL),
('499', 'timezones_ARRAY_-32400', 'arrays', 'timezones_ARRAY_-32400', 'script', NULL),
('500', 'timezones_ARRAY_-28800', 'arrays', 'timezones_ARRAY_-28800', 'script', NULL),
('501', 'timezones_ARRAY_-25200', 'arrays', 'timezones_ARRAY_-25200', 'script', NULL),
('502', 'timezones_ARRAY_-21600', 'arrays', 'timezones_ARRAY_-21600', 'script', NULL),
('503', 'timezones_ARRAY_-18000', 'arrays', 'timezones_ARRAY_-18000', 'script', NULL),
('504', 'timezones_ARRAY_-14400', 'arrays', 'timezones_ARRAY_-14400', 'script', NULL),
('505', 'timezones_ARRAY_-10800', 'arrays', 'timezones_ARRAY_-10800', 'script', NULL),
('506', 'timezones_ARRAY_-7200', 'arrays', 'timezones_ARRAY_-7200', 'script', NULL),
('507', 'timezones_ARRAY_-3600', 'arrays', 'timezones_ARRAY_-3600', 'script', NULL),
('508', 'timezones_ARRAY_0', 'arrays', 'timezones_ARRAY_0', 'script', NULL),
('509', 'timezones_ARRAY_3600', 'arrays', 'timezones_ARRAY_3600', 'script', NULL),
('510', 'timezones_ARRAY_7200', 'arrays', 'timezones_ARRAY_7200', 'script', NULL),
('511', 'timezones_ARRAY_10800', 'arrays', 'timezones_ARRAY_10800', 'script', NULL),
('512', 'timezones_ARRAY_14400', 'arrays', 'timezones_ARRAY_14400', 'script', NULL),
('513', 'timezones_ARRAY_18000', 'arrays', 'timezones_ARRAY_18000', 'script', NULL),
('514', 'timezones_ARRAY_21600', 'arrays', 'timezones_ARRAY_21600', 'script', NULL),
('515', 'timezones_ARRAY_25200', 'arrays', 'timezones_ARRAY_25200', 'script', NULL),
('516', 'timezones_ARRAY_28800', 'arrays', 'timezones_ARRAY_28800', 'script', NULL),
('517', 'timezones_ARRAY_32400', 'arrays', 'timezones_ARRAY_32400', 'script', NULL),
('518', 'timezones_ARRAY_36000', 'arrays', 'timezones_ARRAY_36000', 'script', NULL),
('519', 'timezones_ARRAY_39600', 'arrays', 'timezones_ARRAY_39600', 'script', NULL),
('520', 'timezones_ARRAY_43200', 'arrays', 'timezones_ARRAY_43200', 'script', NULL),
('521', 'timezones_ARRAY_46800', 'arrays', 'timezones_ARRAY_46800', 'script', NULL),
('540', 'error_titles_ARRAY_AU01', 'arrays', 'error_titles_ARRAY_AU01', 'script', NULL),
('541', 'error_titles_ARRAY_AU03', 'arrays', 'error_titles_ARRAY_AU03', 'script', NULL),
('542', 'error_titles_ARRAY_AU04', 'arrays', 'error_titles_ARRAY_AU04', 'script', NULL),
('543', 'error_titles_ARRAY_AU08', 'arrays', 'error_titles_ARRAY_AU08', 'script', NULL),
('544', 'error_titles_ARRAY_AO01', 'arrays', 'error_titles_ARRAY_AO01', 'script', NULL),
('552', 'error_titles_ARRAY_AB01', 'arrays', 'error_titles_ARRAY_AB01', 'script', NULL),
('553', 'error_titles_ARRAY_AB02', 'arrays', 'error_titles_ARRAY_AB02', 'script', NULL),
('554', 'error_titles_ARRAY_AB03', 'arrays', 'error_titles_ARRAY_AB03', 'script', NULL),
('555', 'error_titles_ARRAY_AB04', 'arrays', 'error_titles_ARRAY_AB04', 'script', NULL),
('556', 'error_titles_ARRAY_AA10', 'arrays', 'error_titles_ARRAY_AA10', 'script', NULL),
('557', 'error_titles_ARRAY_AA11', 'arrays', 'error_titles_ARRAY_AA11', 'script', NULL),
('558', 'error_titles_ARRAY_AA12', 'arrays', 'error_titles_ARRAY_AA12', 'script', NULL),
('559', 'error_titles_ARRAY_AA13', 'arrays', 'error_titles_ARRAY_AA13', 'script', NULL),
('578', 'error_bodies_ARRAY_AU01', 'arrays', 'error_bodies_ARRAY_AU01', 'script', NULL),
('579', 'error_bodies_ARRAY_AU03', 'arrays', 'error_bodies_ARRAY_AU03', 'script', NULL),
('580', 'error_bodies_ARRAY_AU04', 'arrays', 'error_bodies_ARRAY_AU04', 'script', NULL),
('581', 'error_bodies_ARRAY_AU08', 'arrays', 'error_bodies_ARRAY_AU08', 'script', NULL),
('582', 'error_bodies_ARRAY_AO01', 'arrays', 'error_bodies_ARRAY_AO01', 'script', NULL),
('589', 'error_bodies_ARRAY_ALC01', 'arrays', 'error_bodies_ARRAY_ALC01', 'script', NULL),
('590', 'error_bodies_ARRAY_AB01', 'arrays', 'error_bodies_ARRAY_AB01', 'script', NULL),
('591', 'error_bodies_ARRAY_AB02', 'arrays', 'error_bodies_ARRAY_AB02', 'script', NULL),
('592', 'error_bodies_ARRAY_AB03', 'arrays', 'error_bodies_ARRAY_AB03', 'script', NULL),
('593', 'error_bodies_ARRAY_AB04', 'arrays', 'error_bodies_ARRAY_AB04', 'script', NULL),
('594', 'error_bodies_ARRAY_AA10', 'arrays', 'error_bodies_ARRAY_AA10', 'script', NULL),
('595', 'error_bodies_ARRAY_AA11', 'arrays', 'error_bodies_ARRAY_AA11', 'script', NULL),
('596', 'error_bodies_ARRAY_AA12', 'arrays', 'error_bodies_ARRAY_AA12', 'script', NULL),
('597', 'error_bodies_ARRAY_AA13', 'arrays', 'error_bodies_ARRAY_AA13', 'script', NULL),
('627', 'months_ARRAY_1', 'arrays', 'months_ARRAY_1', 'script', NULL),
('628', 'months_ARRAY_2', 'arrays', 'months_ARRAY_2', 'script', NULL),
('629', 'months_ARRAY_3', 'arrays', 'months_ARRAY_3', 'script', NULL),
('630', 'months_ARRAY_4', 'arrays', 'months_ARRAY_4', 'script', NULL),
('631', 'months_ARRAY_5', 'arrays', 'months_ARRAY_5', 'script', NULL),
('632', 'months_ARRAY_6', 'arrays', 'months_ARRAY_6', 'script', NULL),
('633', 'months_ARRAY_7', 'arrays', 'months_ARRAY_7', 'script', NULL),
('634', 'months_ARRAY_8', 'arrays', 'months_ARRAY_8', 'script', NULL),
('635', 'months_ARRAY_9', 'arrays', 'months_ARRAY_9', 'script', NULL),
('636', 'months_ARRAY_10', 'arrays', 'months_ARRAY_10', 'script', NULL),
('637', 'months_ARRAY_11', 'arrays', 'months_ARRAY_11', 'script', NULL),
('638', 'months_ARRAY_12', 'arrays', 'months_ARRAY_12', 'script', NULL),
('639', 'days_ARRAY_0', 'arrays', 'days_ARRAY_0', 'script', NULL),
('640', 'days_ARRAY_1', 'arrays', 'days_ARRAY_1', 'script', NULL),
('641', 'days_ARRAY_2', 'arrays', 'days_ARRAY_2', 'script', NULL),
('642', 'days_ARRAY_3', 'arrays', 'days_ARRAY_3', 'script', NULL),
('643', 'days_ARRAY_4', 'arrays', 'days_ARRAY_4', 'script', NULL),
('644', 'days_ARRAY_5', 'arrays', 'days_ARRAY_5', 'script', NULL),
('645', 'days_ARRAY_6', 'arrays', 'days_ARRAY_6', 'script', NULL),
('646', 'day_names_ARRAY_0', 'arrays', 'day_names_ARRAY_0', 'script', NULL),
('647', 'day_names_ARRAY_1', 'arrays', 'day_names_ARRAY_1', 'script', NULL),
('648', 'day_names_ARRAY_2', 'arrays', 'day_names_ARRAY_2', 'script', NULL),
('649', 'day_names_ARRAY_3', 'arrays', 'day_names_ARRAY_3', 'script', NULL),
('650', 'day_names_ARRAY_4', 'arrays', 'day_names_ARRAY_4', 'script', NULL),
('651', 'day_names_ARRAY_5', 'arrays', 'day_names_ARRAY_5', 'script', NULL),
('652', 'day_names_ARRAY_6', 'arrays', 'day_names_ARRAY_6', 'script', NULL),
('653', 'short_months_ARRAY_1', 'arrays', 'short_months_ARRAY_1', 'script', NULL),
('654', 'short_months_ARRAY_2', 'arrays', 'short_months_ARRAY_2', 'script', NULL),
('655', 'short_months_ARRAY_3', 'arrays', 'short_months_ARRAY_3', 'script', NULL),
('656', 'short_months_ARRAY_4', 'arrays', 'short_months_ARRAY_4', 'script', NULL),
('657', 'short_months_ARRAY_5', 'arrays', 'short_months_ARRAY_5', 'script', NULL),
('658', 'short_months_ARRAY_6', 'arrays', 'short_months_ARRAY_6', 'script', NULL),
('659', 'short_months_ARRAY_7', 'arrays', 'short_months_ARRAY_7', 'script', NULL),
('660', 'short_months_ARRAY_8', 'arrays', 'short_months_ARRAY_8', 'script', NULL),
('661', 'short_months_ARRAY_9', 'arrays', 'short_months_ARRAY_9', 'script', NULL),
('662', 'short_months_ARRAY_10', 'arrays', 'short_months_ARRAY_10', 'script', NULL),
('663', 'short_months_ARRAY_11', 'arrays', 'short_months_ARRAY_11', 'script', NULL),
('664', 'short_months_ARRAY_12', 'arrays', 'short_months_ARRAY_12', 'script', NULL),
('665', 'status_ARRAY_1', 'arrays', 'status_ARRAY_1', 'script', NULL),
('666', 'status_ARRAY_2', 'arrays', 'status_ARRAY_2', 'script', NULL),
('667', 'status_ARRAY_3', 'arrays', 'status_ARRAY_3', 'script', NULL),
('668', 'status_ARRAY_7', 'arrays', 'status_ARRAY_7', 'script', NULL),
('669', 'status_ARRAY_123', 'arrays', 'status_ARRAY_123', 'script', NULL),
('670', 'status_ARRAY_999', 'arrays', 'status_ARRAY_999', 'script', NULL),
('671', 'status_ARRAY_998', 'arrays', 'status_ARRAY_998', 'script', NULL),
('672', 'status_ARRAY_997', 'arrays', 'status_ARRAY_997', 'script', NULL),
('673', 'status_ARRAY_996', 'arrays', 'status_ARRAY_996', 'script', NULL),
('674', 'status_ARRAY_9999', 'arrays', 'status_ARRAY_9999', 'script', NULL),
('675', 'status_ARRAY_9998', 'arrays', 'status_ARRAY_9998', 'script', NULL),
('676', 'status_ARRAY_9997', 'arrays', 'status_ARRAY_9997', 'script', NULL),
('677', 'login_err_ARRAY_1', 'arrays', 'login_err_ARRAY_1', 'script', NULL),
('678', 'login_err_ARRAY_2', 'arrays', 'login_err_ARRAY_2', 'script', NULL),
('679', 'login_err_ARRAY_3', 'arrays', 'login_err_ARRAY_3', 'script', NULL),
('907', 'localeArrays', 'backend', 'Locale / Arrays titles', 'script', NULL),
('908', 'infoLocalesArraysTitle', 'backend', 'Locale / Languages Array Title', 'script', NULL),
('909', 'infoLocalesArraysBody', 'backend', 'Locale / Languages Array Body', 'script', NULL),
('910', 'lnkBack', 'backend', 'Link Back', 'script', NULL),
('982', 'locale_order', 'backend', 'Locale / Order', 'script', NULL),
('983', 'locale_is_default', 'backend', 'Locale / Is default', 'script', NULL),
('984', 'locale_flag', 'backend', 'Locale / Flag', 'script', NULL),
('985', 'locale_title', 'backend', 'Locale / Title', 'script', NULL),
('986', 'btnDelete', 'backend', 'Button Delete', 'script', NULL),
('990', 'btnContinue', 'backend', 'Button Continue', 'script', NULL),
('992', 'vr_email_taken', 'backend', 'Users / Email already taken', 'script', NULL),
('993', 'revert_status', 'backend', 'Revert status', 'script', NULL),
('994', 'lblExport', 'backend', 'Export', 'script', NULL),
('995', 'opt_o_send_email', 'backend', 'opt_o_send_email', 'script', NULL),
('996', 'opt_o_smtp_host', 'backend', 'opt_o_smtp_host', 'script', NULL),
('997', 'opt_o_smtp_port', 'backend', 'opt_o_smtp_port', 'script', NULL),
('998', 'opt_o_smtp_user', 'backend', 'opt_o_smtp_user', 'script', NULL),
('999', 'opt_o_smtp_pass', 'backend', 'opt_o_smtp_pass', 'script', NULL),
('1053', 'menuServices', 'backend', 'Menu Services', 'script', '2013-09-16 09:50:50'),
('1054', 'menuEmployees', 'backend', 'Menu Employees', 'script', '2013-09-16 09:51:03'),
('1055', 'service_add', 'backend', 'Services / Add service', 'script', '2013-09-16 12:44:28'),
('1056', 'lblAll', 'backend', 'All', 'script', '2013-09-16 12:47:43'),
('1057', 'service_name', 'backend', 'Services / Name', 'script', '2013-11-22 09:45:50'),
('1058', 'service_price', 'backend', 'Services / Price', 'script', '2013-09-16 12:52:48'),
('1059', 'service_before', 'backend', 'Services / Before', 'script', '2013-09-16 12:53:30'),
('1060', 'service_after', 'backend', 'Services / After', 'script', '2013-09-16 12:53:22'),
('1061', 'service_total', 'backend', 'Services / Total', 'script', '2013-09-16 12:53:41'),
('1062', 'service_length', 'backend', 'Services / Length', 'script', '2013-09-16 12:53:59'),
('1063', 'service_desc', 'backend', 'Services / Description', 'script', '2013-09-16 12:54:18'),
('1064', 'service_status', 'backend', 'Services / Status', 'script', '2013-09-16 12:56:13'),
('1065', 'service_employees', 'backend', 'Services / Employees', 'script', '2013-09-16 12:59:53'),
('1066', 'service_update', 'backend', 'Services / Update service', 'script', '2013-09-16 13:21:54'),
('1067', 'is_active_ARRAY_1', 'arrays', 'is_active_ARRAY_1', 'script', '2013-09-16 13:42:57'),
('1068', 'is_active_ARRAY_0', 'arrays', 'is_active_ARRAY_0', 'script', '2013-09-16 13:43:10'),
('1069', 'delete_selected', 'backend', 'Grid / Delete selected', 'script', '2013-09-16 14:10:00'),
('1070', 'delete_confirmation', 'backend', 'Grid / Confirmation Title', 'script', '2013-09-16 14:09:36'),
('1071', 'error_bodies_ARRAY_AS08', 'arrays', 'error_bodies_ARRAY_AS08', 'script', '2013-09-16 14:11:08'),
('1072', 'error_titles_ARRAY_AS01', 'arrays', 'error_titles_ARRAY_AS01', 'script', '2013-09-16 14:11:21'),
('1073', 'error_titles_ARRAY_AS03', 'arrays', 'error_titles_ARRAY_AS03', 'script', '2013-09-16 14:11:31'),
('1074', 'error_titles_ARRAY_AS04', 'arrays', 'error_titles_ARRAY_AS04', 'script', '2013-09-16 14:11:40'),
('1075', 'error_titles_ARRAY_AS08', 'arrays', 'error_titles_ARRAY_AS08', 'script', '2013-09-16 14:11:48'),
('1076', 'error_bodies_ARRAY_AS01', 'arrays', 'error_bodies_ARRAY_AS01', 'script', '2013-09-16 14:11:58'),
('1077', 'error_bodies_ARRAY_AS03', 'arrays', 'error_bodies_ARRAY_AS03', 'script', '2013-09-16 14:12:09'),
('1078', 'error_bodies_ARRAY_AS04', 'arrays', 'error_bodies_ARRAY_AS04', 'script', '2013-09-16 14:12:21'),
('1079', 'error_titles_ARRAY_AS09', 'arrays', 'error_titles_ARRAY_AS09', 'script', '2013-09-16 14:15:00'),
('1080', 'error_bodies_ARRAY_AS09', 'arrays', 'error_bodies_ARRAY_AS09', 'script', '2013-11-22 09:45:38'),
('1081', 'error_bodies_ARRAY_AS10', 'arrays', 'error_bodies_ARRAY_AS10', 'script', '2013-11-22 09:49:41'),
('1082', 'error_titles_ARRAY_AS10', 'arrays', 'error_titles_ARRAY_AS10', 'script', '2013-09-16 14:15:43'),
('1083', 'employee_add', 'backend', 'Employees / Add employee', 'script', '2013-09-16 14:20:31'),
('1084', 'employee_name', 'backend', 'Employees / Employee Name', 'script', '2013-11-22 09:51:34'),
('1085', 'employee_email', 'backend', 'Employees / Email', 'script', '2013-09-16 14:24:29'),
('1086', 'employee_phone', 'backend', 'Employees / Phone', 'script', '2013-09-16 14:24:39'),
('1087', 'employee_services', 'backend', 'Employees / Services', 'script', '2013-09-16 14:27:56'),
('1088', 'employee_status', 'backend', 'Employees / Status', 'script', '2013-09-16 14:28:41'),
('1089', 'employee_update', 'backend', 'Employees / Update employee', 'script', '2013-09-16 14:37:06'),
('1090', 'error_titles_ARRAY_AE09', 'arrays', 'error_titles_ARRAY_AE09', 'script', '2013-09-16 14:39:06'),
('1091', 'error_titles_ARRAY_AE10', 'arrays', 'error_titles_ARRAY_AE10', 'script', '2013-09-16 14:39:01'),
('1092', 'error_bodies_ARRAY_AE10', 'arrays', 'error_bodies_ARRAY_AE10', 'script', '2013-11-22 09:53:36'),
('1093', 'error_bodies_ARRAY_AE09', 'arrays', 'error_bodies_ARRAY_AE09', 'script', '2013-11-22 09:52:17'),
('1094', 'employee_notes', 'backend', 'Employees / Notes', 'script', '2013-09-16 14:39:25'),
('1095', 'employee_is_subscribed', 'backend', 'Employees / Send email', 'script', '2013-09-17 06:14:14'),
('1096', 'employee_password', 'backend', 'Employees / Password', 'script', '2013-09-17 06:17:21'),
('1098', 'error_bodies_ARRAY_AE01', 'arrays', 'error_bodies_ARRAY_AE01', 'script', '2013-09-17 06:21:08'),
('1099', 'error_titles_ARRAY_AE01', 'arrays', 'error_titles_ARRAY_AE01', 'script', '2013-09-17 06:21:19'),
('1100', 'error_titles_ARRAY_AE03', 'arrays', 'error_titles_ARRAY_AE03', 'script', '2013-09-17 06:22:16'),
('1101', 'error_bodies_ARRAY_AE03', 'arrays', 'error_bodies_ARRAY_AE03', 'script', '2013-09-17 06:22:27'),
('1102', 'error_bodies_ARRAY_AE08', 'arrays', 'error_bodies_ARRAY_AE08', 'script', '2013-09-17 06:24:07'),
('1103', 'error_titles_ARRAY_AE08', 'arrays', 'error_titles_ARRAY_AE08', 'script', '2013-09-17 06:24:15'),
('1104', 'error_titles_ARRAY_AE04', 'arrays', 'error_titles_ARRAY_AE04', 'script', '2013-09-17 06:26:03'),
('1105', 'error_bodies_ARRAY_AE04', 'arrays', 'error_bodies_ARRAY_AE04', 'script', '2013-09-17 06:26:14'),
('1106', 'employee_last_login', 'backend', 'Employees / Last login', 'script', '2013-09-17 06:29:10'),
('1107', 'menuTime', 'backend', 'Menu Working Time', 'script', '2013-09-17 06:50:37'),
('1108', 'error_titles_ARRAY_AT01', 'arrays', 'error_titles_ARRAY_AT01', 'script', '2013-09-17 07:25:21'),
('1109', 'error_bodies_ARRAY_AT01', 'arrays', 'error_bodies_ARRAY_AT01', 'script', '2013-09-17 07:25:34'),
('1110', 'error_titles_ARRAY_AT02', 'arrays', 'error_titles_ARRAY_AT02', 'script', '2013-09-17 07:26:05'),
('1111', 'error_bodies_ARRAY_AT02', 'arrays', 'error_bodies_ARRAY_AT02', 'script', '2013-09-17 07:26:18'),
('1112', 'error_titles_ARRAY_AT03', 'arrays', 'error_titles_ARRAY_AT03', 'script', '2013-09-17 07:26:50'),
('1113', 'error_bodies_ARRAY_AT03', 'arrays', 'error_bodies_ARRAY_AT03', 'script', '2013-09-17 07:26:58'),
('1114', 'error_titles_ARRAY_AT04', 'arrays', 'error_titles_ARRAY_AT04', 'script', '2013-09-17 07:45:33'),
('1115', 'error_bodies_ARRAY_AT04', 'arrays', 'error_bodies_ARRAY_AT04', 'script', '2013-12-12 18:48:05'),
('1116', 'time_update_custom', 'backend', 'Working Time / Update custom', 'script', '2013-09-17 07:47:22'),
('1117', 'time_default', 'backend', 'Working Time / Default', 'script', '2013-09-17 08:42:14'),
('1118', 'time_custom', 'backend', 'Working Time / Custom', 'script', '2013-09-17 07:47:57'),
('1119', 'time_day', 'backend', 'Working Time / Day of week', 'script', '2013-09-17 07:48:09'),
('1120', 'time_from', 'backend', 'Working Time / Start Time', 'script', '2013-09-17 07:48:22'),
('1121', 'time_to', 'backend', 'Working Time / End Time', 'script', '2013-09-17 07:48:36'),
('1122', 'time_is', 'backend', 'Working Time / Is Day off', 'script', '2013-09-17 07:48:49'),
('1123', 'time_date', 'backend', 'Working Time / Date', 'script', '2013-09-17 07:49:03'),
('1124', 'employee_general', 'backend', 'Employees / General', 'script', '2013-09-17 08:41:28'),
('1125', 'time_default_wt', 'backend', 'Working Time / Default Working Time', 'script', '2013-09-17 08:42:43'),
('1126', 'time_custom_wt', 'backend', 'Working Time / Custom Working Time', 'script', '2013-09-17 08:42:55'),
('1127', 'time_lunch_from', 'backend', 'Working Time / Lunch from', 'script', '2013-09-17 10:28:54'),
('1128', 'time_lunch_to', 'backend', 'Working Time / Lunch to', 'script', '2013-09-17 10:29:07'),
('1129', 'menuInstall', 'backend', 'Menu Install', 'script', '2013-09-18 06:04:31'),
('1130', 'menuPreview', 'backend', 'Menu Preview', 'script', '2013-09-18 06:04:43'),
('1131', 'menuBookings', 'backend', 'Menu Bookings', 'script', '2013-09-18 06:05:10'),
('1132', 'menuGeneral', 'backend', 'Menu General', 'script', '2013-09-18 06:17:39'),
('1133', 'menuPayments', 'backend', 'Menu Payments', 'script', '2013-09-18 06:18:26'),
('1134', 'menuBookingForm', 'backend', 'Menu Booking form', 'script', '2013-09-18 06:18:55'),
('1135', 'menuConfirmation', 'backend', 'Menu Confirmation', 'script', '2013-09-18 06:19:13'),
('1136', 'menuTerms', 'backend', 'Menu Terms', 'script', '2013-09-18 06:19:23'),
('1137', 'opt_o_bf_address_1', 'backend', 'Options / Address 1', 'script', '2013-09-18 06:31:09'),
('1138', 'opt_o_bf_captcha', 'backend', 'Options / Captcha', 'script', '2013-09-18 06:31:32'),
('1139', 'opt_o_bf_city', 'backend', 'Options / City', 'script', '2013-09-18 06:31:49'),
('1140', 'opt_o_bf_email', 'backend', 'Options / Email', 'script', '2013-09-18 06:32:09'),
('1141', 'opt_o_bf_name', 'backend', 'Options / Name', 'script', '2013-09-18 06:32:23'),
('1142', 'opt_o_bf_notes', 'backend', 'Options / Notes', 'script', '2013-09-18 06:32:45'),
('1143', 'opt_o_bf_phone', 'backend', 'Options / Phone ', 'script', '2013-09-18 06:33:03'),
('1144', 'opt_o_bf_state', 'backend', 'Options / State', 'script', '2013-09-18 06:33:24'),
('1145', 'opt_o_bf_terms', 'backend', 'Options / Terms', 'script', '2013-09-18 06:33:47'),
('1146', 'opt_o_bf_zip', 'backend', 'Options / Zip', 'script', '2013-09-18 06:34:16'),
('1147', 'opt_o_bf_country', 'backend', 'Options / Country', 'script', '2013-09-18 06:34:36'),
('1148', 'opt_o_paypal_address', 'backend', 'Options / Paypal address', 'script', '2013-09-18 06:35:08'),
('1149', 'opt_o_accept_bookings', 'backend', 'Options / Accept Bookings', 'script', '2013-09-18 06:35:32'),
('1150', 'opt_o_allow_authorize', 'backend', 'Options / Allow Authorize.net', 'script', '2013-09-18 06:36:05'),
('1151', 'opt_o_allow_bank', 'backend', 'Options / Allow Bank', 'script', '2013-11-22 10:06:31'),
('1152', 'opt_o_allow_creditcard', 'backend', 'Options / Allow Credit Card', 'script', '2013-11-22 10:06:17'),
('1153', 'opt_o_allow_paypal', 'backend', 'Options / Allow Paypal', 'script', '2013-09-18 06:37:10'),
('1154', 'opt_o_authorize_key', 'backend', 'Options / Authorize.net transaction key', 'script', '2013-09-18 06:37:43'),
('1155', 'opt_o_authorize_mid', 'backend', 'Options / Authorize.net merchant ID', 'script', '2013-09-18 06:38:01'),
('1156', 'opt_o_bank_account', 'backend', 'Options / Bank account', 'script', '2013-09-18 06:38:18'),
('1157', 'opt_o_deposit', 'backend', 'Options / Deposit', 'script', '2013-11-22 10:08:04'),
('1158', 'opt_o_disable_payments', 'backend', 'Options / Disable payments', 'script', '2013-11-22 10:07:10'),
('1162', 'opt_o_status_if_not_paid', 'backend', 'Options / Default status for booked dates if not paid', 'script', '2013-09-18 06:40:14'),
('1163', 'opt_o_status_if_paid', 'backend', 'Options / Default status for booked dates if paid', 'script', '2013-09-18 06:40:27'),
('1164', 'opt_o_tax', 'backend', 'Options / Tax payment', 'script', '2013-11-22 10:09:27'),
('1165', 'opt_o_thankyou_page', 'backend', 'Options / "Thank you" page location', 'script', '2013-11-22 10:06:53'),
('1166', 'opt_o_authorize_tz', 'backend', 'Options / Authorize.net Time zone', 'script', '2013-09-18 06:41:23'),
('1167', 'opt_o_email_new_reservation', 'backend', 'Options / New booking received', 'script', '2013-09-18 06:41:40'),
('1168', 'opt_o_email_reservation_cancelled', 'backend', 'Options / Booking cancelled', 'script', '2013-09-18 06:41:55'),
('1169', 'opt_o_email_password_reminder', 'backend', 'Notifications / Password reminder', 'script', '2013-09-18 06:42:08'),
('1170', 'opt_o_bf_address_2', 'backend', 'Options / Address 2', 'script', '2013-09-18 06:42:22'),
('1171', 'opt_o_datetime_format', 'backend', 'Options / Datetime format', 'script', '2013-09-18 06:42:36'),
('1172', 'opt_o_authorize_hash', 'backend', 'Options / Authorize.net hash value', 'script', '2013-09-18 06:42:51'),
('1173', 'confirmation_subject', 'backend', 'Confirmation / Email subject', 'script', '2013-09-18 06:51:31'),
('1174', 'confirmation_body', 'backend', 'Confirmation / Email body', 'script', '2013-09-18 06:51:47'),
('1175', 'confirmation_client_confirmation', 'backend', 'Confirmation / Client confirmation title', 'script', '2013-09-18 06:51:59'),
('1176', 'confirmation_client_payment', 'backend', 'Confirmation / Client payment title', 'script', '2013-09-18 06:52:11'),
('1177', 'confirmation_admin_confirmation', 'backend', 'Confirmation / Admin confirmation title', 'script', '2013-09-18 06:52:25'),
('1178', 'confirmation_admin_payment', 'backend', 'Confirmation / Admin payment title', 'script', '2013-09-18 06:52:36'),
('1179', 'lblOptionsTermsURL', 'backend', 'Options / Booking terms URL', 'script', '2013-09-18 06:53:52'),
('1180', 'lblOptionsTermsContent', 'backend', 'Options / Booking terms content', 'script', '2013-09-18 06:54:03'),
('1181', 'booking_add', 'backend', 'Bookings / Add booking', 'script', '2013-09-18 06:57:23'),
('1182', 'booking_statuses_ARRAY_confirmed', 'arrays', 'Bookings / Status: confirmed', 'script', '2013-09-18 06:58:11'),
('1183', 'booking_statuses_ARRAY_pending', 'arrays', 'Bookings / Status: pending', 'script', '2013-09-18 06:58:27'),
('1184', 'booking_statuses_ARRAY_cancelled', 'arrays', 'Bookings / Status: cancelled', 'script', '2013-09-18 06:58:41'),
('1185', 'booking_uuid', 'backend', 'Bookings / Unique ID', 'script', '2013-09-18 06:59:00'),
('1186', 'booking_status', 'backend', 'Bookings / Status', 'script', '2013-09-18 06:59:25'),
('1187', 'booking_update', 'backend', 'Bookings / Update booking', 'script', '2013-09-18 06:59:38'),
('1315', 'booking_cc_exp', 'backend', 'Bookings / CC Exp.date', 'script', '2013-09-18 07:10:17'),
('1316', 'booking_cc_code', 'backend', 'Bookings / CC Code', 'script', '2013-09-18 07:10:32'),
('1317', 'booking_cc_num', 'backend', 'Bookings / CC Number', 'script', '2013-09-18 07:10:47'),
('1318', 'booking_cc_type', 'backend', 'Bookings / CC Type', 'script', '2013-09-18 07:11:00'),
('1319', 'booking_cc_types_ARRAY_maestro', 'arrays', 'booking_cc_types_ARRAY_maestro', 'script', '2013-09-18 07:11:18'),
('1320', 'booking_cc_types_ARRAY_amex', 'arrays', 'booking_cc_types_ARRAY_amex', 'script', '2013-09-18 07:11:33'),
('1321', 'booking_cc_types_ARRAY_mastercard', 'arrays', 'booking_cc_types_ARRAY_mastercard', 'script', '2013-09-18 07:17:32'),
('1322', 'booking_cc_types_ARRAY_visa', 'arrays', 'booking_cc_types_ARRAY_visa', 'script', '2013-09-18 07:17:48'),
('1324', 'booking_phone', 'backend', 'Bookings / Phone', 'script', '2013-09-18 07:18:13'),
('1325', 'booking_email', 'backend', 'Bookings / Email', 'script', '2013-09-18 07:18:22'),
('1326', 'booking_invoice_details', 'backend', 'Bookings / Invoice details', 'script', '2013-09-18 07:18:34'),
('1327', 'booking_create_invoice', 'backend', 'Bookings / Create Invoice', 'script', '2013-09-18 07:35:27'),
('1328', 'booking_customer', 'backend', 'Bookings / Customer details', 'script', '2013-09-18 07:35:44'),
('1329', 'booking_notes', 'backend', 'Bookings / Notes', 'script', '2013-09-18 07:35:58'),
('1330', 'booking_address_2', 'backend', 'Bookings / Address Line 2', 'script', '2013-09-18 07:36:12'),
('1331', 'booking_address_1', 'backend', 'Bookings / Address Line 1', 'script', '2013-09-18 07:36:27'),
('1332', 'booking_name', 'backend', 'Bookings / Name', 'script', '2013-09-18 07:36:41'),
('1333', 'booking_zip', 'backend', 'Bookings / Zip', 'script', '2013-09-18 07:36:53'),
('1334', 'booking_city', 'backend', 'Bookings / City', 'script', '2013-09-18 07:37:06'),
('1335', 'booking_state', 'backend', 'Bookings / State', 'script', '2013-09-18 07:37:22'),
('1336', 'booking_country', 'backend', 'Bookings / Country', 'script', '2013-09-18 07:37:34'),
('1337', 'booking_tab_client', 'backend', 'Bookings / Client', 'script', '2013-09-18 07:37:47'),
('1338', 'booking_tab_details', 'backend', 'Bookings / Booking', 'script', '2013-09-18 07:37:59'),
('1339', 'booking_general', 'backend', 'Bookings / Details', 'script', '2013-09-18 07:38:11'),
('1340', 'booking_choose', 'backend', 'Bookings / Choose', 'script', '2013-09-18 07:38:22'),
('1341', 'booking_payment_method', 'backend', 'Bookings / Payment method', 'script', '2013-09-18 07:38:33'),
('1342', 'booking_price', 'backend', 'Bookings / Price', 'script', '2013-09-18 07:38:44'),
('1344', 'booking_tax', 'backend', 'Bookings / Tax', 'script', '2013-09-18 07:39:07'),
('1345', 'booking_deposit', 'backend', 'Bookings / Deposit', 'script', '2013-09-18 07:47:15'),
('1346', 'booking_total', 'backend', 'Bookings / Total', 'script', '2013-09-18 07:47:27'),
('1347', 'booking_created', 'backend', 'Bookings / Created', 'script', '2013-09-18 07:47:38'),
('1348', 'payment_methods_ARRAY_authorize', 'arrays', 'payment_methods_ARRAY_authorize', 'script', '2013-09-18 07:55:03'),
('1349', 'payment_methods_ARRAY_bank', 'arrays', 'payment_methods_ARRAY_bank', 'script', '2013-09-18 07:55:22'),
('1350', 'payment_methods_ARRAY_creditcard', 'arrays', 'payment_methods_ARRAY_creditcard', 'script', '2013-09-18 07:55:44'),
('1351', 'payment_methods_ARRAY_paypal', 'arrays', 'payment_methods_ARRAY_paypal', 'script', '2013-09-18 07:55:57'),
('1352', 'error_titles_ARRAY_AO24', 'arrays', 'error_titles_ARRAY_AO24', 'script', '2013-09-18 08:44:03'),
('1353', 'error_titles_ARRAY_AO25', 'arrays', 'error_titles_ARRAY_AO25', 'script', '2013-09-18 08:44:26'),
('1354', 'error_titles_ARRAY_AO26', 'arrays', 'error_titles_ARRAY_AO26', 'script', '2013-09-18 08:44:51'),
('1355', 'error_bodies_ARRAY_AO24', 'arrays', 'error_bodies_ARRAY_AO24', 'script', '2013-09-18 08:45:18'),
('1356', 'error_bodies_ARRAY_AO25', 'arrays', 'error_bodies_ARRAY_AO25', 'script', '2013-12-12 19:55:12'),
('1357', 'error_bodies_ARRAY_AO26', 'arrays', 'error_bodies_ARRAY_AO26', 'script', '2013-09-18 08:45:51'),
('1358', 'error_bodies_ARRAY_AO27', 'arrays', 'error_bodies_ARRAY_AO27', 'script', '2013-11-22 10:10:04'),
('1359', 'error_titles_ARRAY_AO27', 'arrays', 'error_titles_ARRAY_AO27', 'script', '2013-09-18 08:47:26'),
('1360', 'error_bodies_ARRAY_AO23', 'arrays', 'error_bodies_ARRAY_AO23', 'script', '2013-11-22 10:05:23'),
('1361', 'error_titles_ARRAY_AO23', 'arrays', 'error_titles_ARRAY_AO23', 'script', '2013-09-18 08:48:23'),
('1362', 'error_bodies_ARRAY_AO21', 'arrays', 'error_bodies_ARRAY_AO21', 'script', '2013-09-18 08:48:36'),
('1363', 'error_titles_ARRAY_AO21', 'arrays', 'error_titles_ARRAY_AO21', 'script', '2013-09-18 08:48:47'),
('1364', 'opt_o_hide_prices', 'backend', 'Options / Hide prices', 'script', '2013-09-18 08:53:41'),
('1365', 'opt_o_step', 'backend', 'Options / Step', 'script', '2013-09-18 08:54:04'),
('1366', 'booking_services', 'backend', 'Bookings / Services', 'script', '2013-09-18 09:04:47'),
('1367', 'employee_avatar', 'backend', 'Employees / Picture', 'script', '2013-09-18 10:22:36'),
('1368', 'employee_avatar_delete', 'backend', 'Employees / Delete picture', 'script', '2013-09-18 11:15:12'),
('1369', 'employee_avatar_dtitle', 'backend', 'Employees / Delete confirmation', 'script', '2013-09-18 11:23:07'),
('1370', 'employee_avatar_dbody', 'backend', 'Employees / Delete content', 'script', '2013-09-18 11:23:46'),
('1371', 'lblInstallJs1_title', 'backend', 'Install / Title', 'script', '2013-09-18 13:30:03'),
('1372', 'lblInstallJs1_body', 'backend', 'Install / Body', 'script', '2013-09-18 13:30:14'),
('1373', 'lblInstallJs1_1', 'backend', 'Install / Step 1', 'script', '2013-09-18 13:30:26'),
('1374', 'lblInstallJs1_2', 'backend', 'Install / Step 2', 'script', '2013-09-18 13:30:37'),
('1375', 'lblInstallJs1_3', 'backend', 'Install / Step 3', 'script', '2013-09-18 13:30:48'),
('1376', 'opt_o_seo_url', 'backend', 'Options / Seo URLs', 'script', '2013-09-19 09:30:09'),
('1377', 'opt_o_time_format', 'backend', 'Options / Time format', 'script', '2013-09-20 07:37:12'),
('1378', 'opt_o_week_numbers', 'backend', 'Options / Show week numbers', 'script', '2013-09-20 09:29:59'),
('1379', 'co_captcha', 'frontend', 'Checkout / Captcha', 'script', '2013-10-03 12:41:20'),
('1380', 'co_select_country', 'frontend', 'Checkout / Select Country', 'script', '2013-10-03 12:41:52'),
('1381', 'co_terms', 'frontend', 'Checkout / Terms', 'script', '2013-10-03 12:42:05'),
('1382', 'co_empty_notice', 'frontend', 'Checkout / Empty notice', 'script', '2013-10-03 12:42:40'),
('1383', 'front_select_payment', 'frontend', 'Frontend / Select Payment method', 'script', '2013-10-03 12:43:12'),
('1384', 'front_select_cc_type', 'frontend', 'Bookings / Select CC Type', 'script', '2013-10-03 12:44:50'),
('1385', 'booking_employee', 'backend', 'Bookings / Employee', 'script', '2013-10-04 13:04:17'),
('1386', 'booking_service', 'backend', 'Bookings / Service', 'script', '2013-10-04 13:04:28'),
('1387', 'booking_from', 'backend', 'Bookings / Date from', 'script', '2013-10-04 13:04:43'),
('1388', 'booking_to', 'backend', 'Bookings / Date to', 'script', '2013-10-04 13:04:51'),
('1389', 'booking_query', 'backend', 'Bookings / Query', 'script', '2013-10-04 13:22:00'),
('1390', 'booking_date', 'backend', 'Bookings / Date', 'script', '2013-10-04 13:57:28'),
('1391', 'booking_export', 'backend', 'Bookings / Export', 'script', '2013-10-07 06:19:11'),
('1392', 'booking_delimiter_ARRAY_comma', 'arrays', 'booking_delimiter_ARRAY_comma', 'script', '2013-10-07 07:13:45'),
('1393', 'booking_delimiter_ARRAY_semicolon', 'arrays', 'booking_delimiter_ARRAY_semicolon', 'script', '2013-10-07 07:13:59'),
('1394', 'booking_delimiter_ARRAY_tab', 'arrays', 'booking_delimiter_ARRAY_tab', 'script', '2013-10-07 07:14:09'),
('1395', 'booking_format_ARRAY_csv', 'arrays', 'booking_delimiter_ARRAY_csv', 'script', '2013-10-07 07:15:01'),
('1396', 'booking_format_ARRAY_xml', 'arrays', 'booking_delimiter_ARRAY_xml', 'script', '2013-10-07 07:15:19'),
('1397', 'booking_format_ARRAY_ical', 'arrays', 'booking_delimiter_ARRAY_ical', 'script', '2013-10-07 07:15:31'),
('1398', 'booking_delimiter_lbl', 'backend', 'Bookings / Delimiter', 'script', '2013-10-07 07:18:41'),
('1399', 'booking_format_lbl', 'backend', 'Bookings / Format', 'script', '2013-10-07 07:18:54'),
('1400', 'booking_na', 'backend', 'Bookings / Not available', 'script', '2013-10-07 09:33:57'),
('1401', 'booking_export_title', 'backend', 'Bookings / Export bookings', 'script', '2013-10-07 09:35:09'),
('1402', 'booking_dt', 'backend', 'Bookings / Date Time', 'script', '2013-10-07 09:48:12'),
('1403', 'booking_service_employee', 'backend', 'Bookings / Service/Employee', 'script', '2013-10-07 09:48:47'),
('1404', 'menuReminder', 'backend', 'Menu Reminder', 'script', '2013-10-07 10:02:28'),
('1405', 'opt_o_reminder_enable', 'backend', 'Options / Enable notifications', 'script', '2013-12-12 19:56:41'),
('1406', 'opt_o_reminder_email_before', 'backend', 'Options / Send email reminder', 'script', '2013-12-12 19:58:20'),
('1407', 'opt_o_reminder_subject', 'backend', 'Options / Email Reminder subject', 'script', '2013-10-07 10:05:19'),
('1408', 'opt_o_reminder_sms_hours', 'backend', 'Options / Send SMS reminder', 'script', '2013-12-12 20:00:13'),
('1410', 'opt_o_reminder_sms_message', 'backend', 'Options / SMS message', 'script', '2013-12-12 20:00:53'),
('1411', 'opt_o_reminder_body', 'backend', 'Options / Email Reminder body', 'script', '2013-12-12 19:58:37'),
('1412', 'get_key', 'backend', 'Options / Get key', 'script', '2013-10-07 10:42:43'),
('1413', 'error_bodies_ARRAY_AO28', 'arrays', 'error_bodies_ARRAY_AO28', 'script', '2013-12-12 20:00:42'),
('1414', 'error_titles_ARRAY_AO28', 'arrays', 'error_titles_ARRAY_AO28', 'script', '2013-10-07 10:44:33'),
('1415', 'error_titles_ARRAY_ABK01', 'arrays', 'error_titles_ARRAY_ABK01', 'script', '2013-10-07 10:48:09'),
('1416', 'error_bodies_ARRAY_ABK01', 'arrays', 'error_bodies_ARRAY_ABK01', 'script', '2013-10-07 10:48:33'),
('1417', 'error_titles_ARRAY_ABK08', 'arrays', 'error_titles_ARRAY_ABK08', 'script', '2013-10-07 10:49:10'),
('1418', 'error_bodies_ARRAY_ABK08', 'arrays', 'error_bodies_ARRAY_ABK08', 'script', '2013-10-07 10:50:05'),
('1419', 'error_titles_ARRAY_ABK03', 'arrays', 'error_titles_ARRAY_ABK03', 'script', '2013-10-07 10:50:42'),
('1420', 'error_bodies_ARRAY_ABK03', 'arrays', 'error_bodies_ARRAY_ABK03', 'script', '2013-10-07 10:51:08'),
('1421', 'error_titles_ARRAY_ABK04', 'arrays', 'error_titles_ARRAY_ABK04', 'script', '2013-10-07 10:51:24'),
('1422', 'error_bodies_ARRAY_ABK04', 'arrays', 'error_bodies_ARRAY_ABK04', 'script', '2013-10-07 10:51:40'),
('1423', 'error_bodies_ARRAY_ABK10', 'arrays', 'error_bodies_ARRAY_ABK10', 'script', '2013-11-22 09:43:28'),
('1424', 'error_titles_ARRAY_ABK10', 'arrays', 'error_titles_ARRAY_ABK10', 'script', '2013-10-07 10:52:49'),
('1425', 'error_titles_ARRAY_ABK11', 'arrays', 'error_titles_ARRAY_ABK11', 'script', '2013-10-07 10:53:28'),
('1426', 'error_bodies_ARRAY_ABK11', 'arrays', 'error_bodies_ARRAY_ABK11', 'script', '2013-11-22 09:44:07'),
('1427', 'error_bodies_ARRAY_ABK13', 'arrays', 'error_bodies_ARRAY_ABK13', 'script', '2013-10-07 10:54:44'),
('1428', 'error_titles_ARRAY_ABK13', 'arrays', 'error_titles_ARRAY_ABK13', 'script', '2013-10-07 10:54:38'),
('1429', 'error_bodies_ARRAY_ABK12', 'arrays', 'error_bodies_ARRAY_ABK12', 'script', '2013-10-07 10:55:06'),
('1430', 'error_titles_ARRAY_ABK12', 'arrays', 'error_titles_ARRAY_ABK12', 'script', '2013-10-07 10:55:13'),
('1431', 'error_bodies_ARRAY_AO08', 'arrays', 'error_bodies_ARRAY_AO08', 'script', '2013-10-07 11:41:38'),
('1432', 'error_titles_ARRAY_AO08', 'arrays', 'error_titles_ARRAY_AO08', 'script', '2013-10-07 11:41:48'),
('1433', 'error_bodies_ARRAY_AO06', 'arrays', 'error_bodies_ARRAY_AO06', 'script', '2013-10-07 11:42:11'),
('1434', 'error_titles_ARRAY_AO06', 'arrays', 'error_titles_ARRAY_AO06', 'script', '2013-10-07 11:42:21'),
('1435', 'error_titles_ARRAY_AO05', 'arrays', 'error_titles_ARRAY_AO05', 'script', '2013-10-07 11:42:43'),
('1436', 'error_bodies_ARRAY_AO05', 'arrays', 'error_bodies_ARRAY_AO05', 'script', '2013-10-07 11:42:58'),
('1437', 'error_bodies_ARRAY_AO04', 'arrays', 'error_bodies_ARRAY_AO04', 'script', '2013-10-07 11:43:43'),
('1438', 'error_titles_ARRAY_AO04', 'arrays', 'error_titles_ARRAY_AO04', 'script', '2013-10-07 11:43:53'),
('1439', 'error_titles_ARRAY_AO07', 'arrays', 'error_titles_ARRAY_AO07', 'script', '2013-10-07 11:44:24'),
('1440', 'error_bodies_ARRAY_AO07', 'arrays', 'error_bodies_ARRAY_AO07', 'script', '2013-10-07 11:44:37'),
('1441', 'error_bodies_ARRAY_AO03', 'arrays', 'error_bodies_ARRAY_AO03', 'script', '2013-10-07 11:45:45'),
('1442', 'error_titles_ARRAY_AO03', 'arrays', 'error_titles_ARRAY_AO03', 'script', '2013-10-07 11:45:39'),
('1454', 'booking_recalc', 'backend', 'Bookings / Recalculate the price', 'script', '2013-10-07 14:34:20'),
('1455', 'booking_service_add', 'backend', 'Bookings / Add service', 'script', '2013-10-07 14:35:29'),
('1456', 'booking_service_add_title', 'backend', 'Bookings / Add service (title)', 'script', '2013-10-07 14:36:58'),
('1457', 'booking_service_delete_title', 'backend', 'Bookings / Remove service (title)', 'script', '2013-10-07 14:38:39'),
('1458', 'booking_service_delete_body', 'backend', 'Bookings / Remove service (body)', 'script', '2013-10-07 14:38:28'),
('1459', 'front_cart_empty', 'frontend', 'Frontend / Cart is empty', 'script', '2013-10-07 15:10:19'),
('1460', 'front_cart_total', 'frontend', 'Frontend / Total', 'script', '2013-10-07 15:10:13'),
('1461', 'front_selected_services', 'frontend', 'Frontend / Selected Services', 'script', '2013-10-07 15:10:07'),
('1462', 'front_select_date', 'frontend', 'Frontend / Select a Date', 'script', '2013-10-07 15:10:01'),
('1463', 'front_make_appointment', 'frontend', 'Frontend / Make an Appointment', 'script', '2013-10-07 15:09:57'),
('1464', 'front_start_time', 'frontend', 'Frontend / Start time', 'script', '2013-10-07 15:09:53'),
('1465', 'front_end_time', 'frontend', 'Frontend / End time', 'script', '2013-10-07 15:10:54'),
('1466', 'front_select_services', 'frontend', 'Frontend / Select Services', 'script', '2013-10-07 15:11:52'),
('1467', 'front_availability', 'frontend', 'Frontend / Availability', 'script', '2013-10-07 15:12:16'),
('1468', 'front_booking_form', 'frontend', 'Frontend / Booking Form', 'script', '2013-10-07 15:12:40'),
('1469', 'front_system_msg', 'frontend', 'Frontend / System message', 'script', '2013-10-07 15:13:54'),
('1470', 'front_checkout_na', 'frontend', 'Frontend / Checkout form not available', 'script', '2013-10-07 15:14:17'),
('1471', 'front_return_back', 'frontend', 'Frontend / Return back', 'script', '2013-10-07 15:14:33'),
('1472', 'front_preview_form', 'frontend', 'Frontend / Booking Preview', 'script', '2013-10-07 15:15:17'),
('1473', 'front_confirm_booking', 'frontend', 'Frontend / Confirm booking', 'script', '2013-10-07 15:16:08'),
('1474', 'front_preview_na', 'frontend', 'Frontend / Preview not available', 'script', '2013-10-07 15:16:58'),
('1475', 'error_titles_ARRAY_AA14', 'arrays', 'error_titles_ARRAY_AA14', 'script', '2013-10-09 09:00:13'),
('1476', 'error_bodies_ARRAY_AA14', 'arrays', 'error_bodies_ARRAY_AA14', 'script', '2013-10-09 09:00:47'),
('1477', 'error_titles_ARRAY_AA15', 'arrays', 'error_titles_ARRAY_AA15', 'script', '2013-10-09 09:01:59'),
('1478', 'error_bodies_ARRAY_AA15', 'arrays', 'error_bodies_ARRAY_AA15', 'script', '2013-10-09 09:02:18'),
('1479', 'booking_ip', 'backend', 'Bookings / IP address', 'script', '2013-10-09 12:04:45'),
('1480', 'booking_view_title', 'backend', 'Bookings / Booking Service details', 'script', '2013-10-09 12:11:48'),
('1481', 'booking_service_email_title', 'backend', 'Bookings / Resend email (title)', 'script', '2013-10-09 12:51:52'),
('1482', 'booking_service_sms_title', 'backend', 'Bookings / Resend SMS (title)', 'script', '2013-10-09 12:52:05'),
('1483', 'booking_subject', 'backend', 'Bookings / Subject', 'script', '2013-10-09 13:36:00'),
('1484', 'booking_message', 'backend', 'Bookings / Message', 'script', '2013-10-09 13:36:13'),
('1485', 'menuReports', 'backend', 'Menu Reports', 'script', '2013-10-09 14:30:39'),
('1486', 'report_menu_employees', 'backend', 'Reports / Employees menu', 'script', '2013-10-09 14:37:45'),
('1487', 'report_menu_services', 'backend', 'Reports / Services menu', 'script', '2013-10-09 14:37:57'),
('1488', 'report_bookings', 'backend', 'Reports / Bookings', 'script', '2013-10-09 14:50:10'),
('1489', 'report_total_bookings', 'backend', 'Reports / Total bookings', 'script', '2013-10-10 06:21:58'),
('1490', 'report_confirmed_bookings', 'backend', 'Reports / Confirmed bookings', 'script', '2013-10-10 06:22:19'),
('1491', 'report_pending_bookings', 'backend', 'Reports / Pending bookings', 'script', '2013-10-10 06:22:35'),
('1492', 'report_cancelled_bookings', 'backend', 'Reports / Cancelled bookings', 'script', '2013-10-10 06:22:48'),
('1493', 'report_total_amount', 'backend', 'Reports / Total amount', 'script', '2013-10-10 06:23:28'),
('1494', 'report_confirmed_amount', 'backend', 'Reports / Confirmed Bookings Amount', 'script', '2013-10-10 06:23:47'),
('1495', 'report_pending_amount', 'backend', 'Reports / Pending Bookings Amount', 'script', '2013-10-10 06:24:09'),
('1496', 'report_cancelled_amount', 'backend', 'Reports / Cancelled Bookings Amount', 'script', '2013-10-10 06:24:26'),
('1497', 'report_columns', 'backend', 'Reports / Columns', 'script', '2013-10-10 11:55:19'),
('1498', 'report_print', 'backend', 'Reports / Print', 'script', '2013-10-10 13:36:52'),
('1499', 'report_pdf', 'backend', 'Reports / Save as PDF', 'script', '2013-10-11 06:18:31'),
('1500', 'menu', 'backend', 'Menu', 'script', '2013-11-11 09:22:39'),
('1501', 'employee_view_bookings', 'backend', 'Employees / View bookings', 'script', '2013-11-11 09:23:31'),
('1502', 'employee_working_time', 'backend', 'Employees / Working time', 'script', '2013-11-11 09:23:57'),
('1503', 'error_titles_ARRAY_AS11', 'arrays', 'error_titles_ARRAY_AS11', 'script', '2013-11-11 09:46:01'),
('1504', 'error_bodies_ARRAY_AS11', 'arrays', 'error_bodies_ARRAY_AS11', 'script', '2013-11-22 09:44:50'),
('1505', 'service_tip_length', 'backend', 'Services / Length tooltip', 'script', '2013-11-22 09:46:30'),
('1506', 'service_tip_before', 'backend', 'Services / Before tooltip', 'script', '2013-11-22 09:47:47'),
('1507', 'service_tip_after', 'backend', 'Services / After tooltip', 'script', '2013-11-22 09:48:28'),
('1508', 'service_tip_employees', 'backend', 'Services / Employees tooltip', 'script', '2013-11-11 10:05:28'),
('1509', 'employee_is_subscribed_sms', 'backend', 'Employees / Send sms', 'script', '2013-11-11 12:34:31'),
('1510', 'booking_reminder_client', 'backend', 'Bookings / Send to client', 'script', '2013-11-11 12:58:52'),
('1511', 'booking_reminder_employee', 'backend', 'Bookings / Send to employee', 'script', '2013-11-11 12:59:04'),
('1512', 'front_click_available', 'frontend', 'Frontend / Click on available time', 'script', '2013-11-12 08:29:47'),
('1514', 'error_titles_ARRAY_AE11', 'arrays', 'error_titles_ARRAY_AE11', 'script', '2013-11-18 07:36:16'),
('1515', 'error_bodies_ARRAY_AE11', 'arrays', 'error_bodies_ARRAY_AE11', 'script', '2013-11-22 09:50:21'),
('1530', 'menuSeo', 'backend', 'Menu SEO', 'script', '2013-11-18 08:37:13'),
('1531', 'lblInstallConfig', 'backend', 'Install / Config', 'script', '2013-11-18 08:40:41'),
('1532', 'lblInstallConfigLocale', 'backend', 'Install / Locale', 'script', '2013-11-18 08:40:54'),
('1533', 'lblInstallConfigHide', 'backend', 'Install / Config hide', 'script', '2013-11-18 08:41:05'),
('1534', 'error_bodies_ARRAY_AO30', 'arrays', 'error_titles_ARRAY_AO30', 'script', '2013-11-18 08:45:15'),
('1535', 'error_titles_ARRAY_AO30', 'arrays', 'error_titles_ARRAY_AO30', 'script', '2013-11-18 08:45:32'),
('1536', 'lblInstallSeo_1', 'backend', 'Install / SEO Step 1', 'script', '2013-11-18 08:46:19'),
('1537', 'lblInstallSeo_2', 'backend', 'Install / SEO Step 2', 'script', '2013-11-18 08:47:16'),
('1538', 'lblInstallSeo_3', 'backend', 'Install / SEO Step 3', 'script', '2013-11-18 08:47:33'),
('1539', 'btnGenerate', 'backend', 'Generate', 'script', '2013-11-18 10:11:06'),
('1540', 'booking_index', 'backend', 'Bookings / Index', 'script', '2013-11-18 10:31:03'),
('1541', 'error_titles_ARRAY_AR01', 'arrays', 'error_titles_ARRAY_AR01', 'script', '2013-11-19 07:05:22'),
('1542', 'error_bodies_ARRAY_AR01', 'arrays', 'error_bodies_ARRAY_AR01', 'script', '2013-11-26 11:30:50'),
('1543', 'error_titles_ARRAY_AR02', 'arrays', 'error_titles_ARRAY_AR02', 'script', '2013-11-19 08:58:03'),
('1544', 'error_bodies_ARRAY_AR02', 'arrays', 'error_bodies_ARRAY_AR02', 'script', '2013-11-26 11:32:22'),
('1545', 'report_amount', 'backend', 'Reports / Amount', 'script', '2013-11-19 09:11:38'),
('1546', 'report_cnt', 'backend', 'Reports / Count', 'script', '2013-11-19 09:11:47'),
('1547', 'error_bodies_ARRAY_AD01', 'arrays', 'error_titles_ARRAY_AD01', 'script', '2013-11-26 11:28:15'),
('1548', 'error_titles_ARRAY_AD01', 'arrays', 'error_titles_ARRAY_AD01', 'script', '2013-11-19 14:39:41'),
('1549', 'btnApply', 'backend', 'Save', 'script', '2013-11-19 15:19:53'),
('1550', 'dashboard_filter', 'backend', 'Dashboard / Filter', 'script', '2013-11-19 15:20:36'),
('1756', 'error_titles_ARRAY_AT05', 'arrays', 'error_titles_ARRAY_AT05', 'script', '2013-12-12 18:48:22'),
('1758', 'error_bodies_ARRAY_AT05', 'arrays', 'error_bodies_ARRAY_AT05', 'script', '2013-12-12 18:49:38'),
('1759', 'error_bodies_ARRAY_AT06', 'arrays', 'error_bodies_ARRAY_AT06', 'script', '2013-12-12 18:57:00'),
('1760', 'error_titles_ARRAY_AT06', 'arrays', 'error_titles_ARRAY_AT06', 'script', '2013-12-12 18:44:11'),
('1761', 'error_titles_ARRAY_AT07', 'arrays', 'error_titles_ARRAY_AT07', 'script', '2013-12-12 18:57:15'),
('1762', 'error_bodies_ARRAY_AT07', 'arrays', 'error_bodies_ARRAY_AT07', 'script', '2013-12-12 19:35:49'),
('1768', 'btnToday', 'backend', 'Button / Today', 'script', '2013-11-25 09:07:23'),
('1769', 'btnTomorrow', 'backend', 'Button / Tomorrow', 'script', '2013-11-25 09:07:53'),
('1770', 'error_titles_ARRAY_AD02', 'arrays', 'error_titles_ARRAY_AD02', 'script', '2013-11-25 10:58:52'),
('1771', 'error_bodies_ARRAY_AD02', 'arrays', 'error_titles_ARRAY_AD02', 'script', '2013-11-25 10:59:14'),
('1772', 'payment_paypal_submit', 'frontend', 'Frontend / Paypal submit', 'script', '2013-12-18 10:49:09'),
('1773', 'payment_authorize_submit', 'frontend', 'Frontend / Authorize.NET submit', 'script', '2013-12-18 10:49:31'),
('1774', 'front_booking_status_ARRAY_11', 'arrays', 'front_booking_status_ARRAY_11', 'script', '2013-12-18 10:51:14'),
('1775', 'front_booking_status_ARRAY_1', 'arrays', 'front_booking_status_ARRAY_1', 'script', '2013-12-18 10:51:29'),
('1776', 'front_booking_status_ARRAY_4', 'arrays', 'front_booking_status_ARRAY_4', 'script', '2013-12-18 10:52:17'),
('1777', 'front_booking_status_ARRAY_3', 'arrays', 'front_booking_status_ARRAY_3', 'script', '2013-12-18 10:56:19'),
('1778', 'front_booking_na', 'frontend', 'Frontend / Booking not available', 'script', '2013-12-18 12:19:33'),
('1779', 'booking_start_time', 'backend', 'Bookings / Start time', 'script', '2013-12-18 13:58:57'),
('1780', 'booking_end_time', 'backend', 'Bookings / End time', 'script', '2013-12-18 13:59:11'),
('1781', 'error_titles_ARRAY_ABK14', 'arrays', 'error_titles_ARRAY_ABK14', 'script', '2013-12-18 14:26:25'),
('1782', 'error_bodies_ARRAY_ABK14', 'arrays', 'error_bodies_ARRAY_ABK14', 'script', '2013-12-18 14:27:17'),
('1783', 'error_titles_ARRAY_ABK15', 'arrays', 'error_titles_ARRAY_ABK15', 'script', '2013-12-18 14:49:29'),
('1784', 'error_bodies_ARRAY_ABK15', 'arrays', 'error_bodies_ARRAY_ABK15', 'script', '2013-12-18 14:50:19'),
('1785', 'front_minutes', 'frontend', 'Frontend / Minutes', 'script', '2014-01-09 09:50:10'),
('1790', 'front_on', 'frontend', 'Frontend / On', 'script', '2014-01-09 12:29:55'),
('1791', 'front_back_services', 'backend', 'Frontend / Back to services', 'script', '2014-01-09 12:39:14'),
('1792', 'front_checkout', 'frontend', 'Frontend / Checkout', 'script', '2014-01-09 12:55:52'),
('1793', 'front_cart_done', 'frontend', 'Frontend / Service added', 'script', '2014-01-09 12:56:53'),
('1794', 'front_app_ARRAY_v_remote', 'arrays', 'front_app_ARRAY_v_remote', 'script', '2014-01-09 15:12:14'),
('1795', 'front_from', 'backend', 'Frontend / From', 'script', '2014-01-09 15:41:17'),
('1796', 'front_till', 'backend', 'Frontend / Till', 'script', '2014-01-09 15:41:28'),
('1797', 'cancel_err_ARRAY_1', 'arrays', 'cancel_err_ARRAY_1', 'script', '2014-01-22 07:55:23'),
('1798', 'cancel_err_ARRAY_2', 'arrays', 'cancel_err_ARRAY_2', 'script', '2014-01-22 07:56:24'),
('1799', 'cancel_err_ARRAY_3', 'arrays', 'cancel_err_ARRAY_3', 'script', '2014-01-22 07:56:17'),
('1800', 'cancel_err_ARRAY_4', 'arrays', 'cancel_err_ARRAY_4', 'script', '2014-01-22 07:56:38'),
('1801', 'cancel_err_ARRAY_5', 'arrays', 'cancel_err_ARRAY_5', 'script', '2014-01-22 07:57:02'),
('1802', 'cancel_details', 'frontend', 'Cancel / Customer Details', 'script', '2014-01-22 08:42:56'),
('1803', 'cancel_confirm', 'frontend', 'Cancel / Cancel button', 'script', '2014-01-22 08:41:25'),
('1804', 'cancel_services', 'frontend', 'Cancel / Booking Services', 'script', '2014-01-22 08:42:33'),
('1805', 'cancel_title', 'frontend', 'Cancel / Page title', 'script', '2014-01-22 08:43:29'),
('1806', 'confirmation_employee_confirmation', 'backend', 'Confirmation / Employee confirmation title', 'script', '2014-01-30 07:19:10'),
('1807', 'confirmation_employee_payment', 'backend', 'Confirmation / Employee payment title', 'script', '2014-01-30 07:19:16'),
('1808', 'time_update_default', 'backend', 'Working Time / Update default working time', 'script', '2014-01-30 09:04:39'),
('1809', 'opt_o_layout', 'backend', 'Options / Layout', 'script', '2014-02-06 09:05:31'),
('1810', 'front_single_date', 'frontend', 'Single / Select date', 'script', '2014-02-06 10:36:29'),
('1811', 'front_single_service', 'frontend', 'Single / Service', 'script', '2014-02-06 10:36:52'),
('1812', 'front_single_time', 'frontend', 'Single / Select time', 'script', '2014-02-06 10:37:06'),
('1813', 'front_single_employee', 'frontend', 'Single / Employee', 'script', '2014-02-06 10:37:37'),
('1814', 'btnBook', 'backend', 'Button / Book', 'script', '2014-02-06 10:41:10'),
('1815', 'front_single_date_service', 'frontend', 'Single / Select date and service', 'script', '2014-02-06 10:41:55'),
('1816', 'front_single_choose_date', 'frontend', 'Single / Choose date', 'script', '2014-02-06 10:45:32'),
('1817', 'single_date', 'frontend', 'Single / Date', 'script', '2014-02-10 14:04:43'),
('1818', 'single_price', 'frontend', 'Single / Price', 'script', '2014-02-10 14:04:53'),
('1819', 'front_booking_status_ARRAY_5', 'arrays', 'front_booking_status_ARRAY_5', 'script', '2014-02-17 07:38:07'),
('1820', 'front_single_na', 'frontend', 'Single / Not available', 'script', '2014-02-20 15:21:19'),
('1821', 'btnCheckout', 'backend', 'Button Checkout', 'script', '2014-06-03 12:51:42'),
('1822', 'btnBackToServices', 'backend', 'Button Back to services', 'script', '2014-06-03 12:52:25'),
('1823', 'btnViewCart', 'backend', 'Button View cart', 'script', '2014-06-03 13:00:56'),
('1824', 'error_titles_ARRAY_AU10', 'arrays', 'error_titles_ARRAY_AU10', 'script', '2014-06-03 14:01:07'),
('1825', 'error_bodies_ARRAY_AU10', 'arrays', 'error_bodies_ARRAY_AU10', 'script', '2014-06-03 14:02:39'),
('1826', 'front_terms_link', 'frontend', 'Frontend / Read terms and conditions', 'script', '2014-06-03 14:18:42'),
('1827', 'front_app_ARRAY_btn_ok', 'arrays', 'front_app_ARRAY_btn_ok', 'script', '2014-06-03 14:24:26'),
('1828', 'front_terms', 'frontend', 'Frontend / Terms and Conditions', 'script', '2014-06-03 14:25:59'),
('1829', 'front_cart_tax', 'frontend', 'Frontend / Tax', 'script', '2014-06-03 14:54:27'),
('1830', 'front_cart_deposit', 'frontend', 'Frontend / Deposit', 'script', '2014-06-03 14:54:59'),
('1831', 'front_cart_price', 'frontend', 'Frontend / Price', 'script', '2014-06-03 14:55:31'),
('2049', 'co_v_captcha', 'frontend', 'Checkout / Validation / Captcha', 'script', '2014-06-24 07:26:46'),
('2050', 'co_v_captcha_remote', 'frontend', 'Checkout / Validation / Captcha remote', 'script', '2014-06-24 07:27:15'),
('2051', 'co_v_terms', 'frontend', 'Checkout / Validation / Terms', 'script', '2014-06-24 07:27:46'),
('2052', 'co_v_notes', 'frontend', 'Checkout / Validation / Notes', 'script', '2014-06-24 07:28:07'),
('2053', 'co_v_zip', 'frontend', 'Checkout / Validation / Zip', 'script', '2014-06-24 07:28:17'),
('2054', 'co_v_city', 'frontend', 'Checkout / Validation / City', 'script', '2014-06-24 07:28:26'),
('2055', 'co_v_state', 'frontend', 'Checkout / Validation / State', 'script', '2014-06-24 07:28:34'),
('2056', 'co_v_country', 'frontend', 'Checkout / Validation / Country', 'script', '2014-06-24 07:28:43'),
('2058', 'co_v_address_1', 'frontend', 'Checkout / Validation / Address Line 1', 'script', '2014-06-24 07:29:12'),
('2059', 'co_v_address_2', 'frontend', 'Checkout / Validation / Address Line 2', 'script', '2014-06-24 07:29:21'),
('2060', 'co_v_phone', 'frontend', 'Checkout / Validation / Phone', 'script', '2014-06-24 07:29:36'),
('2061', 'co_v_name', 'frontend', 'Checkout / Validation / Name', 'script', '2014-06-24 07:29:47'),
('2062', 'co_v_email', 'frontend', 'Checkout / Validation / Email', 'script', '2014-06-24 07:29:57'),
('2063', 'co_v_email_inv', 'frontend', 'Checkout / Validation / Email invalid', 'script', '2014-06-24 07:30:18'),
('2064', 'co_v_payment', 'frontend', 'Checkout / Validation / Payment', 'script', '2014-06-24 07:32:03'),
('2065', 'co_v_cc_type', 'frontend', 'Checkout / Validation / CC Type', 'script', '2014-06-24 07:33:20'),
('2066', 'co_v_cc_num', 'frontend', 'Checkout / Validation / CC Number', 'script', '2014-06-24 07:33:34'),
('2067', 'co_v_cc_code', 'frontend', 'Checkout / Validation / CC Code', 'script', '2014-06-24 07:33:45'),
('2068', 'form_v_required', 'backend', 'Form / Validation / Required', 'script', '2014-06-24 08:06:37'),
('2069', 'form_v_remote', 'backend', 'Form / Validation / Remote', 'script', '2014-06-24 07:53:07'),
('2070', 'form_v_email', 'backend', 'Form / Validation / Email', 'script', '2014-06-24 07:53:05'),
('2071', 'form_v_url', 'backend', 'Form / Validation / URL', 'script', '2014-06-24 07:53:02'),
('2072', 'form_v_date', 'backend', 'Form / Validation / Date', 'script', '2014-06-24 07:52:59'),
('2073', 'form_v_date_iso', 'backend', 'Form / Validation / Date ISO', 'script', '2014-06-24 07:52:55'),
('2074', 'form_v_number', 'backend', 'Form / Validation / Number', 'script', '2014-06-24 07:52:52'),
('2075', 'form_v_digits', 'backend', 'Form / Validation / Digits', 'script', '2014-06-24 07:52:48'),
('2076', 'form_v_creditcard', 'backend', 'Form / Validation / Creditcard', 'script', '2014-06-24 07:52:44'),
('2077', 'form_v_equal_to', 'backend', 'Form / Validation / Equal to', 'script', '2014-06-24 07:52:41'),
('2078', 'form_v_maxlength', 'backend', 'Form / Validation / Maxlength', 'script', '2014-06-24 07:52:36'),
('2079', 'form_v_minlength', 'backend', 'Form / Validation / Minlength', 'script', '2014-06-24 07:52:32'),
('2080', 'form_v_rangelength', 'backend', 'Form / Validation / Range length', 'script', '2014-06-24 07:52:28'),
('2081', 'form_v_range', 'backend', 'Form / Validation / Range', 'script', '2014-06-24 07:52:25'),
('2082', 'form_v_max', 'backend', 'Form / Validation / Max', 'script', '2014-06-24 07:52:22'),
('2083', 'form_v_min', 'backend', 'Form / Validation / Min', 'script', '2014-06-24 07:52:19'),
('2084', 'form_v_accept', 'backend', 'Form / Validation / Accept', 'script', '2014-06-24 07:52:15'),
('2085', 'front_day_suffix_ARRAY_1', 'arrays', 'Frontend / Day suffix: 1', 'script', '2014-06-24 08:47:10'),
('2086', 'front_day_suffix_ARRAY_2', 'arrays', 'Frontend / Day suffix: 2', 'script', '2014-06-24 08:47:24'),
('2087', 'front_day_suffix_ARRAY_3', 'arrays', 'Frontend / Day suffix: 3', 'script', '2014-06-24 08:47:32'),
('2088', 'front_day_suffix_ARRAY_4', 'arrays', 'Frontend / Day suffix: 4', 'script', '2014-06-24 08:47:43'),
('2089', 'front_day_suffix_ARRAY_5', 'arrays', 'Frontend / Day suffix: 5', 'script', '2014-06-24 08:47:51'),
('2090', 'front_day_suffix_ARRAY_6', 'arrays', 'Frontend / Day suffix: 6', 'script', '2014-06-24 08:47:57'),
('2091', 'front_day_suffix_ARRAY_7', 'arrays', 'Frontend / Day suffix: 7', 'script', '2014-06-24 08:48:02'),
('2092', 'front_day_suffix_ARRAY_8', 'arrays', 'Frontend / Day suffix: 8', 'script', '2014-06-24 08:48:07'),
('2093', 'front_day_suffix_ARRAY_9', 'arrays', 'Frontend / Day suffix: 9', 'script', '2014-06-24 08:48:13'),
('2094', 'front_day_suffix_ARRAY_10', 'arrays', 'Frontend / Day suffix: 10', 'script', '2014-06-24 08:48:19'),
('2095', 'front_day_suffix_ARRAY_11', 'arrays', 'Frontend / Day suffix: 11', 'script', '2014-06-24 08:48:31'),
('2096', 'front_day_suffix_ARRAY_12', 'arrays', 'Frontend / Day suffix: 12', 'script', '2014-06-24 08:48:41'),
('2097', 'front_day_suffix_ARRAY_13', 'arrays', 'Frontend / Day suffix: 13', 'script', '2014-06-24 08:48:47'),
('2098', 'front_day_suffix_ARRAY_14', 'arrays', 'Frontend / Day suffix: 14', 'script', '2014-06-24 08:48:52'),
('2099', 'front_day_suffix_ARRAY_15', 'arrays', 'Frontend / Day suffix: 15', 'script', '2014-06-24 08:48:58'),
('2100', 'front_day_suffix_ARRAY_16', 'arrays', 'Frontend / Day suffix: 16', 'script', '2014-06-24 08:49:04'),
('2101', 'front_day_suffix_ARRAY_17', 'arrays', 'Frontend / Day suffix: 17', 'script', '2014-06-24 08:49:09'),
('2102', 'front_day_suffix_ARRAY_18', 'arrays', 'Frontend / Day suffix: 18', 'script', '2014-06-24 08:49:14'),
('2103', 'front_day_suffix_ARRAY_19', 'arrays', 'Frontend / Day suffix: 19', 'script', '2014-06-24 08:49:19'),
('2104', 'front_day_suffix_ARRAY_20', 'arrays', 'Frontend / Day suffix: 20', 'script', '2014-06-24 08:49:25'),
('2105', 'front_day_suffix_ARRAY_21', 'arrays', 'Frontend / Day suffix: 21', 'script', '2014-06-24 08:49:48'),
('2106', 'front_day_suffix_ARRAY_22', 'arrays', 'Frontend / Day suffix: 22', 'script', '2014-06-24 08:49:43'),
('2107', 'front_day_suffix_ARRAY_23', 'arrays', 'Frontend / Day suffix: 23', 'script', '2014-06-24 08:49:59'),
('2108', 'front_day_suffix_ARRAY_24', 'arrays', 'Frontend / Day suffix: 24', 'script', '2014-06-24 08:50:06'),
('2109', 'front_day_suffix_ARRAY_25', 'arrays', 'Frontend / Day suffix: 25', 'script', '2014-06-24 08:50:13'),
('2110', 'front_day_suffix_ARRAY_26', 'arrays', 'Frontend / Day suffix: 26', 'script', '2014-06-24 08:50:18'),
('2111', 'front_day_suffix_ARRAY_27', 'arrays', 'Frontend / Day suffix: 27', 'script', '2014-06-24 08:50:23'),
('2112', 'front_day_suffix_ARRAY_28', 'arrays', 'Frontend / Day suffix: 28', 'script', '2014-06-24 08:50:27'),
('2113', 'front_day_suffix_ARRAY_29', 'arrays', 'Frontend / Day suffix: 29', 'script', '2014-06-24 08:50:33'),
('2114', 'front_day_suffix_ARRAY_30', 'arrays', 'Frontend / Day suffix: 30', 'script', '2014-06-24 08:50:40'),
('2115', 'front_day_suffix_ARRAY_31', 'arrays', 'Frontend / Day suffix: 31', 'script', '2014-06-24 08:50:48'),
('2116', 'front_service_na', 'frontend', 'Frontend / Service not available', 'script', '2014-06-25 14:23:57'),
('2117', 'front_day_na', 'frontend', 'Frontend / Day not available', 'script', '2014-06-25 14:46:22'),
('2118', 'multiselect_check_all', 'backend', 'MultiSelect / Check all', 'script', '2014-07-14 07:21:31'),
('2119', 'multiselect_uncheck_all', 'backend', 'MultiSelect / Uncheck all', 'script', '2014-07-14 07:21:41'),
('2120', 'multiselect_none_selected', 'backend', 'MultiSelect / Select options', 'script', '2014-07-14 07:22:06'),
('2121', 'multiselect_selected', 'backend', 'MultiSelect / # selected', 'script', '2014-07-14 07:22:27'),
('2122', 'confirmation_client_cancel', 'backend', 'Confirmation / Client cancellation title', 'script', '2014-07-14 10:24:38'),
('2123', 'confirmation_employee_cancel', 'backend', 'Confirmation / Employee cancellation title', 'script', '2014-07-14 10:26:17'),
('2124', 'confirmation_admin_cancel', 'backend', 'Confirmation / Admin cancellation title', 'script', '2014-07-14 10:27:07'),
('2374', 'system_206', 'frontend', 'System / Service added', 'script', '2014-08-25 07:54:47'),
('2375', 'system_105', 'frontend', 'System / Missing data', 'script', '2014-08-25 07:54:29'),
('2376', 'system_207', 'frontend', 'System / Service removed', 'script', '2014-08-25 07:53:58'),
('2377', 'system_106', 'frontend', 'System / Missing data', 'script', '2014-08-25 07:53:29'),
('2378', 'system_109', 'frontend', 'System / Checkout data is missing', 'script', '2014-08-25 07:52:47'),
('2379', 'system_110', 'frontend', 'System / Captcha doesn''t match', 'script', '2014-08-25 07:51:42'),
('2380', 'system_111', 'frontend', 'System / Cart is empty', 'script', '2014-08-25 07:50:42'),
('2381', 'system_114', 'frontend', 'System / Booking data is invalid', 'script', '2014-08-25 07:48:20'),
('2382', 'system_119', 'frontend', 'System / Booking failed', 'script', '2014-08-25 07:47:15'),
('2383', 'system_211', 'frontend', 'System / Checkout form saved', 'script', '2014-08-25 07:45:45'),
('2384', 'system_115', 'frontend', 'System / Service not available', 'script', '2014-08-25 07:55:13'),
('2385', 'system_210', 'frontend', 'System / Booking saved', 'script', '2014-08-25 07:47:29');

INSERT INTO `appscheduler_multi_lang` VALUES
('1', '5', 'pjField', '1', 'title', 'Username', 'script'),
('2', '6', 'pjField', '1', 'title', 'Password', 'script'),
('3', '7', 'pjField', '1', 'title', 'Email', 'script'),
('4', '8', 'pjField', '1', 'title', 'URL', 'script'),
('5', '13', 'pjField', '1', 'title', 'DateTime', 'script'),
('6', '16', 'pjField', '1', 'title', 'Save', 'script'),
('7', '17', 'pjField', '1', 'title', 'Reset', 'script'),
('8', '18', 'pjField', '1', 'title', 'Add language', 'script'),
('9', '22', 'pjField', '1', 'title', 'Multi Lang', 'script'),
('10', '23', 'pjField', '1', 'title', 'Plugins', 'script'),
('11', '24', 'pjField', '1', 'title', 'Users', 'script'),
('12', '25', 'pjField', '1', 'title', 'Options', 'script'),
('13', '26', 'pjField', '1', 'title', 'Logout', 'script'),
('14', '31', 'pjField', '1', 'title', 'Update', 'script'),
('15', '36', 'pjField', '1', 'title', 'Choose', 'script'),
('16', '37', 'pjField', '1', 'title', 'Search', 'script'),
('17', '40', 'pjField', '1', 'title', 'Back-end titles', 'script'),
('18', '41', 'pjField', '1', 'title', 'Front-end titles', 'script'),
('19', '42', 'pjField', '1', 'title', 'Languages', 'script'),
('20', '44', 'pjField', '1', 'title', 'Admin Login', 'script'),
('21', '45', 'pjField', '1', 'title', 'Login', 'script'),
('22', '47', 'pjField', '1', 'title', 'Dashboard', 'script'),
('23', '57', 'pjField', '1', 'title', 'Option list', 'script'),
('24', '58', 'pjField', '1', 'title', 'Add +', 'script'),
('25', '62', 'pjField', '1', 'title', 'Delete', 'script'),
('26', '65', 'pjField', '1', 'title', 'Type', 'script'),
('27', '66', 'pjField', '1', 'title', 'Name', 'script'),
('28', '67', 'pjField', '1', 'title', 'Role', 'script'),
('29', '68', 'pjField', '1', 'title', 'Status', 'script'),
('30', '69', 'pjField', '1', 'title', 'Is confirmed', 'script'),
('31', '70', 'pjField', '1', 'title', 'Update user', 'script'),
('32', '71', 'pjField', '1', 'title', 'Add user', 'script'),
('33', '72', 'pjField', '1', 'title', 'Value', 'script'),
('34', '73', 'pjField', '1', 'title', 'Option', 'script'),
('35', '74', 'pjField', '1', 'title', 'days', 'script'),
('36', '115', 'pjField', '1', 'title', 'Languages', 'script'),
('73', '116', 'pjField', '1', 'title', 'Yes', 'script'),
('75', '117', 'pjField', '1', 'title', 'No', 'script'),
('77', '338', 'pjField', '1', 'title', 'Error', 'script'),
('79', '347', 'pjField', '1', 'title', '&laquo; Back', 'script'),
('81', '355', 'pjField', '1', 'title', 'Cancel', 'script'),
('83', '356', 'pjField', '1', 'title', 'Forgot password', 'script'),
('85', '357', 'pjField', '1', 'title', 'Password reminder', 'script'),
('87', '358', 'pjField', '1', 'title', 'Send', 'script'),
('89', '359', 'pjField', '1', 'title', 'Password reminder', 'script'),
('91', '360', 'pjField', '1', 'title', 'Dear {Name},Your password: {Password}', 'script'),
('93', '365', 'pjField', '1', 'title', 'Profile', 'script'),
('95', '380', 'pjField', '1', 'title', 'Languages Title', 'script'),
('97', '381', 'pjField', '1', 'title', 'Languages Body', 'script'),
('99', '382', 'pjField', '1', 'title', 'Languages Backend Title', 'script'),
('101', '383', 'pjField', '1', 'title', 'Languages Backend Body', 'script'),
('103', '384', 'pjField', '1', 'title', 'Languages Frontend Title', 'script'),
('105', '385', 'pjField', '1', 'title', 'Languages Frontend Body', 'script'),
('107', '386', 'pjField', '1', 'title', 'Listing Prices Title', 'script'),
('109', '387', 'pjField', '1', 'title', 'Listing Prices Body', 'script'),
('111', '388', 'pjField', '1', 'title', 'Listing Bookings Title', 'script'),
('113', '389', 'pjField', '1', 'title', 'Listing Bookings Body', 'script'),
('115', '390', 'pjField', '1', 'title', 'Listing Contact Title', 'script'),
('117', '391', 'pjField', '1', 'title', 'Listing Contact Body', 'script'),
('119', '392', 'pjField', '1', 'title', 'Listing Address Title', 'script'),
('121', '393', 'pjField', '1', 'title', 'Listing Address Body', 'script'),
('123', '395', 'pjField', '1', 'title', 'Extend exp.date Title', 'script'),
('125', '396', 'pjField', '1', 'title', 'Extend exp.date Body', 'script'),
('127', '408', 'pjField', '1', 'title', 'Backup', 'script'),
('129', '409', 'pjField', '1', 'title', 'Backup', 'script'),
('131', '410', 'pjField', '1', 'title', 'Backup database', 'script'),
('133', '411', 'pjField', '1', 'title', 'Backup files', 'script'),
('135', '412', 'pjField', '1', 'title', 'Choose Action', 'script'),
('137', '413', 'pjField', '1', 'title', 'Go to page:', 'script'),
('139', '414', 'pjField', '1', 'title', 'Total items:', 'script'),
('141', '415', 'pjField', '1', 'title', 'Items per page', 'script'),
('143', '416', 'pjField', '1', 'title', 'Prev page', 'script'),
('145', '417', 'pjField', '1', 'title', '&laquo; Prev', 'script'),
('147', '418', 'pjField', '1', 'title', 'Next page', 'script'),
('149', '419', 'pjField', '1', 'title', 'Next &raquo;', 'script'),
('151', '420', 'pjField', '1', 'title', 'Delete confirmation', 'script'),
('153', '421', 'pjField', '1', 'title', 'Are you sure you want to delete selected record?', 'script'),
('155', '422', 'pjField', '1', 'title', 'Action confirmation', 'script'),
('157', '423', 'pjField', '1', 'title', 'OK', 'script'),
('159', '424', 'pjField', '1', 'title', 'Cancel', 'script'),
('161', '425', 'pjField', '1', 'title', 'Delete', 'script'),
('163', '426', 'pjField', '1', 'title', 'No records found', 'script'),
('165', '433', 'pjField', '1', 'title', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.', 'script'),
('167', '434', 'pjField', '1', 'title', 'IP address', 'script'),
('169', '435', 'pjField', '1', 'title', 'Registration date/time', 'script'),
('171', '441', 'pjField', '1', 'title', 'Currency', 'script'),
('173', '442', 'pjField', '1', 'title', 'Date format', 'script'),
('175', '451', 'pjField', '1', 'title', 'Timezone', 'script'),
('177', '452', 'pjField', '1', 'title', 'First day of the week', 'script'),
('179', '455', 'pjField', '1', 'title', 'Active', 'script'),
('180', '456', 'pjField', '1', 'title', 'Inactive', 'script'),
('181', '457', 'pjField', '1', 'title', 'Active', 'script'),
('182', '458', 'pjField', '1', 'title', 'Inactive', 'script'),
('183', '471', 'pjField', '1', 'title', 'Yes', 'script'),
('184', '472', 'pjField', '1', 'title', 'No', 'script'),
('185', '476', 'pjField', '1', 'title', 'Mr.', 'script'),
('186', '477', 'pjField', '1', 'title', 'Mrs.', 'script'),
('187', '478', 'pjField', '1', 'title', 'Miss', 'script'),
('188', '479', 'pjField', '1', 'title', 'Ms.', 'script'),
('189', '480', 'pjField', '1', 'title', 'Dr.', 'script'),
('190', '481', 'pjField', '1', 'title', 'Prof.', 'script'),
('191', '482', 'pjField', '1', 'title', 'Rev.', 'script'),
('192', '483', 'pjField', '1', 'title', 'Other', 'script'),
('193', '496', 'pjField', '1', 'title', 'GMT-12:00', 'script'),
('194', '497', 'pjField', '1', 'title', 'GMT-11:00', 'script'),
('195', '498', 'pjField', '1', 'title', 'GMT-10:00', 'script'),
('196', '499', 'pjField', '1', 'title', 'GMT-09:00', 'script'),
('197', '500', 'pjField', '1', 'title', 'GMT-08:00', 'script'),
('198', '501', 'pjField', '1', 'title', 'GMT-07:00', 'script'),
('199', '502', 'pjField', '1', 'title', 'GMT-06:00', 'script'),
('200', '503', 'pjField', '1', 'title', 'GMT-05:00', 'script'),
('201', '504', 'pjField', '1', 'title', 'GMT-04:00', 'script'),
('202', '505', 'pjField', '1', 'title', 'GMT-03:00', 'script'),
('203', '506', 'pjField', '1', 'title', 'GMT-02:00', 'script'),
('204', '507', 'pjField', '1', 'title', 'GMT-01:00', 'script'),
('205', '508', 'pjField', '1', 'title', 'GMT', 'script'),
('206', '509', 'pjField', '1', 'title', 'GMT+01:00', 'script'),
('207', '510', 'pjField', '1', 'title', 'GMT+02:00', 'script'),
('208', '511', 'pjField', '1', 'title', 'GMT+03:00', 'script'),
('209', '512', 'pjField', '1', 'title', 'GMT+04:00', 'script'),
('210', '513', 'pjField', '1', 'title', 'GMT+05:00', 'script'),
('211', '514', 'pjField', '1', 'title', 'GMT+06:00', 'script'),
('212', '515', 'pjField', '1', 'title', 'GMT+07:00', 'script'),
('213', '516', 'pjField', '1', 'title', 'GMT+08:00', 'script'),
('214', '517', 'pjField', '1', 'title', 'GMT+09:00', 'script'),
('215', '518', 'pjField', '1', 'title', 'GMT+10:00', 'script'),
('216', '519', 'pjField', '1', 'title', 'GMT+11:00', 'script'),
('217', '520', 'pjField', '1', 'title', 'GMT+12:00', 'script'),
('218', '521', 'pjField', '1', 'title', 'GMT+13:00', 'script'),
('219', '540', 'pjField', '1', 'title', 'User updated!', 'script'),
('220', '541', 'pjField', '1', 'title', 'User added!', 'script'),
('221', '542', 'pjField', '1', 'title', 'User failed to add.', 'script'),
('222', '543', 'pjField', '1', 'title', 'User not found.', 'script'),
('223', '544', 'pjField', '1', 'title', 'Options updated!', 'script'),
('224', '552', 'pjField', '1', 'title', 'Backup', 'script'),
('225', '553', 'pjField', '1', 'title', 'Backup complete!', 'script'),
('226', '554', 'pjField', '1', 'title', 'Backup failed!', 'script'),
('227', '555', 'pjField', '1', 'title', 'Backup failed!', 'script'),
('228', '556', 'pjField', '1', 'title', 'Account not found!', 'script'),
('229', '557', 'pjField', '1', 'title', 'Password send!', 'script'),
('230', '558', 'pjField', '1', 'title', 'Password not send!', 'script'),
('231', '559', 'pjField', '1', 'title', 'Profile updated!', 'script'),
('232', '578', 'pjField', '1', 'title', 'All the changes made to this user have been saved.', 'script'),
('233', '579', 'pjField', '1', 'title', 'All the changes made to this user have been saved.', 'script'),
('234', '580', 'pjField', '1', 'title', 'We are sorry, but the user has not been added.', 'script'),
('235', '581', 'pjField', '1', 'title', 'User your looking for is missing.', 'script'),
('236', '582', 'pjField', '1', 'title', 'All the changes made to options have been saved.', 'script'),
('237', '589', 'pjField', '1', 'title', 'All the changes made to titles have been saved.', 'script'),
('238', '590', 'pjField', '1', 'title', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc at ligula non arcu dignissim pretium. Praesent in magna nulla, in porta leo.', 'script'),
('239', '591', 'pjField', '1', 'title', 'All backup files have been saved.', 'script'),
('240', '592', 'pjField', '1', 'title', 'No option was selected.', 'script'),
('241', '593', 'pjField', '1', 'title', 'Backup not performed.', 'script'),
('242', '594', 'pjField', '1', 'title', 'Given email address is not associated with any account.', 'script'),
('243', '595', 'pjField', '1', 'title', 'For further instructions please check your mailbox.', 'script'),
('244', '596', 'pjField', '1', 'title', 'We''re sorry, please try again later.', 'script'),
('245', '597', 'pjField', '1', 'title', 'All the changes made to your profile have been saved.', 'script'),
('246', '627', 'pjField', '1', 'title', 'January', 'script'),
('247', '628', 'pjField', '1', 'title', 'February', 'script'),
('248', '629', 'pjField', '1', 'title', 'March', 'script'),
('249', '630', 'pjField', '1', 'title', 'April', 'script'),
('250', '631', 'pjField', '1', 'title', 'May', 'script'),
('251', '632', 'pjField', '1', 'title', 'June', 'script'),
('252', '633', 'pjField', '1', 'title', 'July', 'script'),
('253', '634', 'pjField', '1', 'title', 'August', 'script'),
('254', '635', 'pjField', '1', 'title', 'September', 'script'),
('255', '636', 'pjField', '1', 'title', 'October', 'script'),
('256', '637', 'pjField', '1', 'title', 'November', 'script'),
('257', '638', 'pjField', '1', 'title', 'December', 'script'),
('258', '639', 'pjField', '1', 'title', 'Sunday', 'script'),
('259', '640', 'pjField', '1', 'title', 'Monday', 'script'),
('260', '641', 'pjField', '1', 'title', 'Tuesday', 'script'),
('261', '642', 'pjField', '1', 'title', 'Wednesday', 'script'),
('262', '643', 'pjField', '1', 'title', 'Thursday', 'script'),
('263', '644', 'pjField', '1', 'title', 'Friday', 'script'),
('264', '645', 'pjField', '1', 'title', 'Saturday', 'script'),
('265', '646', 'pjField', '1', 'title', 'S', 'script'),
('266', '647', 'pjField', '1', 'title', 'M', 'script'),
('267', '648', 'pjField', '1', 'title', 'T', 'script'),
('268', '649', 'pjField', '1', 'title', 'W', 'script'),
('269', '650', 'pjField', '1', 'title', 'T', 'script'),
('270', '651', 'pjField', '1', 'title', 'F', 'script'),
('271', '652', 'pjField', '1', 'title', 'S', 'script'),
('272', '653', 'pjField', '1', 'title', 'Jan', 'script'),
('273', '654', 'pjField', '1', 'title', 'Feb', 'script'),
('274', '655', 'pjField', '1', 'title', 'Mar', 'script'),
('275', '656', 'pjField', '1', 'title', 'Apr', 'script'),
('276', '657', 'pjField', '1', 'title', 'May', 'script'),
('277', '658', 'pjField', '1', 'title', 'Jun', 'script'),
('278', '659', 'pjField', '1', 'title', 'Jul', 'script'),
('279', '660', 'pjField', '1', 'title', 'Aug', 'script'),
('280', '661', 'pjField', '1', 'title', 'Sep', 'script'),
('281', '662', 'pjField', '1', 'title', 'Oct', 'script'),
('282', '663', 'pjField', '1', 'title', 'Nov', 'script'),
('283', '664', 'pjField', '1', 'title', 'Dec', 'script'),
('284', '665', 'pjField', '1', 'title', 'You are not loged in.', 'script'),
('285', '666', 'pjField', '1', 'title', 'Access denied. You have not requisite rights to.', 'script'),
('286', '667', 'pjField', '1', 'title', 'Empty resultset.', 'script'),
('287', '668', 'pjField', '1', 'title', 'The operation is not allowed in demo mode.', 'script'),
('288', '669', 'pjField', '1', 'title', 'Your hosting account does not allow uploading such a large image.', 'script'),
('289', '670', 'pjField', '1', 'title', 'No permisions to edit the property', 'script'),
('290', '671', 'pjField', '1', 'title', 'No permisions to edit the reservation', 'script'),
('291', '672', 'pjField', '1', 'title', 'No reservation found', 'script'),
('292', '673', 'pjField', '1', 'title', 'No property for the reservation found', 'script'),
('293', '674', 'pjField', '1', 'title', 'Your registration was successfull.', 'script'),
('294', '675', 'pjField', '1', 'title', 'Your registration was successfull. Your account needs to be approved.', 'script'),
('295', '676', 'pjField', '1', 'title', 'E-Mail address already exist', 'script'),
('296', '677', 'pjField', '1', 'title', 'Wrong username or password', 'script'),
('297', '678', 'pjField', '1', 'title', 'Access denied', 'script'),
('298', '679', 'pjField', '1', 'title', 'Account is disabled', 'script'),
('419', '907', 'pjField', '1', 'title', 'Arrays titles', 'script'),
('421', '908', 'pjField', '1', 'title', 'Languages Arrays Title', 'script'),
('423', '909', 'pjField', '1', 'title', 'Languages Array Body', 'script'),
('425', '910', 'pjField', '1', 'title', 'Back', 'script'),
('427', '982', 'pjField', '1', 'title', 'Order', 'script'),
('429', '983', 'pjField', '1', 'title', 'Is default', 'script'),
('431', '984', 'pjField', '1', 'title', 'Flag', 'script'),
('433', '985', 'pjField', '1', 'title', 'Title', 'script'),
('435', '986', 'pjField', '1', 'title', 'Delete', 'script'),
('437', '990', 'pjField', '1', 'title', 'Continue', 'script'),
('439', '992', 'pjField', '1', 'title', 'Email address is already in use', 'script'),
('441', '993', 'pjField', '1', 'title', 'Revert status', 'script'),
('443', '994', 'pjField', '1', 'title', 'Export', 'script'),
('667', '995', 'pjField', '1', 'title', 'Send email', 'script'),
('670', '996', 'pjField', '1', 'title', 'SMTP Host', 'script'),
('673', '997', 'pjField', '1', 'title', 'SMTP Port', 'script'),
('676', '998', 'pjField', '1', 'title', 'SMTP Username', 'script'),
('679', '999', 'pjField', '1', 'title', 'SMTP Password', 'script'),
('1034', '1053', 'pjField', '1', 'title', 'Services', 'script'),
('1035', '1054', 'pjField', '1', 'title', 'Employees', 'script'),
('1036', '1055', 'pjField', '1', 'title', 'Add service', 'script'),
('1037', '1056', 'pjField', '1', 'title', 'All', 'script'),
('1038', '1057', 'pjField', '1', 'title', 'Service name', 'script'),
('1039', '1058', 'pjField', '1', 'title', 'Price', 'script'),
('1040', '1059', 'pjField', '1', 'title', 'Before (minutes)', 'script'),
('1041', '1060', 'pjField', '1', 'title', 'After (minutes)', 'script'),
('1043', '1061', 'pjField', '1', 'title', 'Total (minutes)', 'script'),
('1044', '1062', 'pjField', '1', 'title', 'Length (minutes)', 'script'),
('1045', '1063', 'pjField', '1', 'title', 'Service description', 'script'),
('1046', '1064', 'pjField', '1', 'title', 'Status', 'script'),
('1047', '1065', 'pjField', '1', 'title', 'Employees', 'script'),
('1048', '1066', 'pjField', '1', 'title', 'Update service', 'script'),
('1049', '1067', 'pjField', '1', 'title', 'Active', 'script'),
('1051', '1068', 'pjField', '1', 'title', 'Inactive', 'script'),
('1063', '1069', 'pjField', '1', 'title', 'Delete selected', 'script'),
('1064', '1070', 'pjField', '1', 'title', 'Are you sure you want to delete selected records?', 'script'),
('1066', '1071', 'pjField', '1', 'title', 'Service your are looking for is missing.', 'script'),
('1067', '1072', 'pjField', '1', 'title', 'Service updated!', 'script'),
('1068', '1073', 'pjField', '1', 'title', 'Service added!', 'script'),
('1069', '1074', 'pjField', '1', 'title', 'Service failed to add.', 'script'),
('1070', '1075', 'pjField', '1', 'title', 'Service not found.', 'script'),
('1071', '1076', 'pjField', '1', 'title', 'All the changes made to this service have been saved.', 'script'),
('1072', '1077', 'pjField', '1', 'title', 'All the changes made to this service have been saved.', 'script'),
('1073', '1078', 'pjField', '1', 'title', 'We are sorry, but the service has not been added.', 'script'),
('1078', '1079', 'pjField', '1', 'title', 'Add a service', 'script'),
('1079', '1080', 'pjField', '1', 'title', 'Fill in the form below to add a new service. You can add title, description, price, length and employees who do this service.', 'script'),
('1080', '1081', 'pjField', '1', 'title', 'Use the form below to modify the service. You can change title, description, price, length and employees who do this service.', 'script'),
('1081', '1082', 'pjField', '1', 'title', 'Update a service', 'script'),
('1084', '1083', 'pjField', '1', 'title', 'Add employee', 'script'),
('1085', '1084', 'pjField', '1', 'title', 'Employee name', 'script'),
('1086', '1085', 'pjField', '1', 'title', 'Email', 'script'),
('1087', '1086', 'pjField', '1', 'title', 'Phone', 'script'),
('1088', '1087', 'pjField', '1', 'title', 'Services', 'script'),
('1089', '1088', 'pjField', '1', 'title', 'Status', 'script'),
('1093', '1089', 'pjField', '1', 'title', 'Update employee', 'script'),
('1095', '1090', 'pjField', '1', 'title', 'Add an employee', 'script'),
('1096', '1091', 'pjField', '1', 'title', 'Update an employee', 'script'),
('1097', '1092', 'pjField', '1', 'title', 'Use the form below to update employee''s details. You can select the service that this employee does. You can also configure it so an email and/or sms notification is sent to the employee when a booking is made. Each employee can access the Appointment Scheduler and manage his/her bookings only.', 'script'),
('1098', '1093', 'pjField', '1', 'title', 'Fill in the form below to add a new employee. You can select the service that this employee does. You can also configure it so an email and/or sms notification is sent to the employee when a booking is made. Each employee can access the Appointment Scheduler and manage his/her bookings only.', 'script'),
('1101', '1094', 'pjField', '1', 'title', 'Notes', 'script'),
('1102', '1095', 'pjField', '1', 'title', 'Send email when new booking is made', 'script'),
('1104', '1096', 'pjField', '1', 'title', 'Password', 'script'),
('1109', '1098', 'pjField', '1', 'title', 'All the changes made to this employee have been saved.', 'script'),
('1110', '1099', 'pjField', '1', 'title', 'Employee updated!', 'script'),
('1112', '1100', 'pjField', '1', 'title', 'Employee added!', 'script'),
('1113', '1101', 'pjField', '1', 'title', 'All the changes made to this employee have been saved.', 'script'),
('1114', '1102', 'pjField', '1', 'title', 'Employee your are looking for is missing.', 'script'),
('1115', '1103', 'pjField', '1', 'title', 'Employee not found.', 'script'),
('1116', '1104', 'pjField', '1', 'title', 'Employee failed to add.', 'script'),
('1117', '1105', 'pjField', '1', 'title', 'We are sorry, but the employee has not been added.', 'script'),
('1118', '1106', 'pjField', '1', 'title', 'Last login', 'script'),
('1119', '1107', 'pjField', '1', 'title', 'Working Time', 'script'),
('1121', '1108', 'pjField', '1', 'title', 'Working Time updated!', 'script'),
('1122', '1109', 'pjField', '1', 'title', 'All the changes made to working time have been saved.', 'script'),
('1123', '1110', 'pjField', '1', 'title', 'Custom Working Time saved!', 'script'),
('1124', '1111', 'pjField', '1', 'title', 'All the changes made to custom working time have been saved.', 'script'),
('1125', '1112', 'pjField', '1', 'title', 'Custom Working Time updated!', 'script'),
('1126', '1113', 'pjField', '1', 'title', 'All the changes made to custom working time have been saved.', 'script'),
('1127', '1114', 'pjField', '1', 'title', 'Working Time', 'script'),
('1128', '1115', 'pjField', '1', 'title', 'Different working time can be set for each day of the week. You can also set days off and a lunch break. Under Edit Employee page you can set up custom working time for each of your employees.', 'script'),
('1129', '1116', 'pjField', '1', 'title', 'Update custom', 'script'),
('1130', '1117', 'pjField', '1', 'title', 'Default', 'script'),
('1131', '1118', 'pjField', '1', 'title', 'Custom', 'script'),
('1132', '1119', 'pjField', '1', 'title', 'Day of week', 'script'),
('1133', '1120', 'pjField', '1', 'title', 'Start Time', 'script'),
('1134', '1121', 'pjField', '1', 'title', 'End Time', 'script'),
('1135', '1122', 'pjField', '1', 'title', 'Is Day off', 'script'),
('1136', '1123', 'pjField', '1', 'title', 'Date', 'script'),
('1141', '1124', 'pjField', '1', 'title', 'General', 'script'),
('1144', '1125', 'pjField', '1', 'title', 'Default Working Time', 'script'),
('1145', '1126', 'pjField', '1', 'title', 'Custom Working Time', 'script'),
('1146', '1127', 'pjField', '1', 'title', 'Lunch from', 'script'),
('1147', '1128', 'pjField', '1', 'title', 'Lunch to', 'script'),
('1148', '1129', 'pjField', '1', 'title', 'Install', 'script'),
('1149', '1130', 'pjField', '1', 'title', 'Preview', 'script'),
('1150', '1131', 'pjField', '1', 'title', 'Bookings', 'script'),
('1151', '1132', 'pjField', '1', 'title', 'General', 'script'),
('1152', '1133', 'pjField', '1', 'title', 'Payments', 'script'),
('1153', '1134', 'pjField', '1', 'title', 'Booking form', 'script'),
('1154', '1135', 'pjField', '1', 'title', 'Confirmation', 'script'),
('1155', '1136', 'pjField', '1', 'title', 'Terms', 'script'),
('1156', '1137', 'pjField', '1', 'title', 'Address 1', 'script'),
('1157', '1138', 'pjField', '1', 'title', 'Captcha', 'script'),
('1158', '1139', 'pjField', '1', 'title', 'City', 'script'),
('1159', '1140', 'pjField', '1', 'title', 'Email', 'script'),
('1160', '1141', 'pjField', '1', 'title', 'Name', 'script'),
('1161', '1142', 'pjField', '1', 'title', 'Notes', 'script'),
('1162', '1143', 'pjField', '1', 'title', 'Phone', 'script'),
('1164', '1144', 'pjField', '1', 'title', 'State', 'script'),
('1165', '1145', 'pjField', '1', 'title', 'Terms', 'script'),
('1166', '1146', 'pjField', '1', 'title', 'Zip', 'script'),
('1167', '1147', 'pjField', '1', 'title', 'Country', 'script'),
('1168', '1148', 'pjField', '1', 'title', 'Paypal address', 'script'),
('1169', '1149', 'pjField', '1', 'title', 'Accept Bookings', 'script'),
('1170', '1150', 'pjField', '1', 'title', 'Allow payments with Authorize.net', 'script'),
('1171', '1151', 'pjField', '1', 'title', 'Provide Bank account details for wire transfers', 'script'),
('1172', '1152', 'pjField', '1', 'title', 'Collect Credit Card details for offline processing', 'script'),
('1173', '1153', 'pjField', '1', 'title', 'Allow payments with PayPal', 'script'),
('1174', '1154', 'pjField', '1', 'title', 'Authorize.net transaction key', 'script'),
('1175', '1155', 'pjField', '1', 'title', 'Authorize.net merchant ID', 'script'),
('1176', '1156', 'pjField', '1', 'title', 'Bank account', 'script'),
('1177', '1157', 'pjField', '1', 'title', 'Set deposit amount to be collected for each appointment', 'script'),
('1178', '1158', 'pjField', '1', 'title', 'Check if you want to disable payments and only collect reservation details', 'script'),
('1182', '1162', 'pjField', '1', 'title', 'Default status for booked dates if not paid', 'script'),
('1183', '1163', 'pjField', '1', 'title', 'Default status for booked dates if paid', 'script'),
('1184', '1164', 'pjField', '1', 'title', 'Tax amount to be collected for each appointment', 'script'),
('1185', '1165', 'pjField', '1', 'title', 'URL for the web page where your clients will be redirected after PayPal or Authorize.net payment', 'script'),
('1186', '1166', 'pjField', '1', 'title', 'Authorize.net time zone', 'script'),
('1187', '1167', 'pjField', '1', 'title', 'New reservation received', 'script'),
('1188', '1168', 'pjField', '1', 'title', 'Reservation cancelled', 'script'),
('1189', '1169', 'pjField', '1', 'title', 'Password reminder', 'script'),
('1190', '1170', 'pjField', '1', 'title', 'Address 2', 'script'),
('1191', '1171', 'pjField', '1', 'title', 'Date/Time format', 'script'),
('1192', '1172', 'pjField', '1', 'title', 'Authorize.net hash value', 'script'),
('1193', '1173', 'pjField', '1', 'title', 'Subject', 'script'),
('1195', '1174', 'pjField', '1', 'title', 'Email body', 'script'),
('1196', '1175', 'pjField', '1', 'title', 'Client - booking confirmation email', 'script'),
('1197', '1176', 'pjField', '1', 'title', 'Client - payment confirmation email', 'script'),
('1198', '1177', 'pjField', '1', 'title', 'Admin - booking confirmation email', 'script'),
('1199', '1178', 'pjField', '1', 'title', 'Admin - payment confirmation email', 'script'),
('1200', '1179', 'pjField', '1', 'title', 'Booking terms URL', 'script'),
('1201', '1180', 'pjField', '1', 'title', 'Booking terms content', 'script'),
('1202', '1181', 'pjField', '1', 'title', 'Add booking', 'script'),
('1203', '1182', 'pjField', '1', 'title', 'Confirmed', 'script'),
('1205', '1183', 'pjField', '1', 'title', 'Pending', 'script'),
('1206', '1184', 'pjField', '1', 'title', 'Cancelled', 'script'),
('1207', '1185', 'pjField', '1', 'title', 'Unique ID', 'script'),
('1208', '1186', 'pjField', '1', 'title', 'Status', 'script'),
('1209', '1187', 'pjField', '1', 'title', 'Update booking', 'script'),
('1337', '1315', 'pjField', '1', 'title', 'CC Exp.date', 'script'),
('1338', '1316', 'pjField', '1', 'title', 'CC Code', 'script'),
('1339', '1317', 'pjField', '1', 'title', 'CC Number', 'script'),
('1340', '1318', 'pjField', '1', 'title', 'CC Type', 'script'),
('1341', '1319', 'pjField', '1', 'title', 'Maestro', 'script'),
('1342', '1320', 'pjField', '1', 'title', 'AmericanExpress', 'script'),
('1343', '1321', 'pjField', '1', 'title', 'MasterCard', 'script'),
('1344', '1322', 'pjField', '1', 'title', 'Visa', 'script'),
('1346', '1324', 'pjField', '1', 'title', 'Phone', 'script'),
('1347', '1325', 'pjField', '1', 'title', 'Email', 'script'),
('1348', '1326', 'pjField', '1', 'title', 'Invoice details', 'script'),
('1349', '1327', 'pjField', '1', 'title', 'Create Invoice', 'script'),
('1350', '1328', 'pjField', '1', 'title', 'Customer details', 'script'),
('1351', '1329', 'pjField', '1', 'title', 'Notes', 'script'),
('1352', '1330', 'pjField', '1', 'title', 'Address Line 2', 'script'),
('1353', '1331', 'pjField', '1', 'title', 'Address Line 1', 'script'),
('1354', '1332', 'pjField', '1', 'title', 'Name', 'script'),
('1355', '1333', 'pjField', '1', 'title', 'Zip', 'script'),
('1356', '1334', 'pjField', '1', 'title', 'City', 'script'),
('1357', '1335', 'pjField', '1', 'title', 'State', 'script'),
('1358', '1336', 'pjField', '1', 'title', 'Country', 'script'),
('1359', '1337', 'pjField', '1', 'title', 'Client', 'script'),
('1360', '1338', 'pjField', '1', 'title', 'Booking', 'script'),
('1361', '1339', 'pjField', '1', 'title', 'Booking details', 'script'),
('1362', '1340', 'pjField', '1', 'title', '-- Choose --', 'script'),
('1363', '1341', 'pjField', '1', 'title', 'Payment method', 'script'),
('1364', '1342', 'pjField', '1', 'title', 'Price', 'script'),
('1366', '1344', 'pjField', '1', 'title', 'Tax', 'script'),
('1367', '1345', 'pjField', '1', 'title', 'Deposit', 'script'),
('1368', '1346', 'pjField', '1', 'title', 'Total', 'script'),
('1369', '1347', 'pjField', '1', 'title', 'Created', 'script'),
('1370', '1348', 'pjField', '1', 'title', 'Authorize.net', 'script'),
('1371', '1349', 'pjField', '1', 'title', 'Bank account', 'script'),
('1372', '1350', 'pjField', '1', 'title', 'Credit card', 'script'),
('1373', '1351', 'pjField', '1', 'title', 'Paypal', 'script'),
('1374', '1352', 'pjField', '1', 'title', 'Booking form', 'script'),
('1375', '1353', 'pjField', '1', 'title', 'Confirmation', 'script'),
('1376', '1354', 'pjField', '1', 'title', 'Terms', 'script'),
('1378', '1355', 'pjField', '1', 'title', 'Choose the fields that should be available on the booking form.', 'script'),
('1379', '1356', 'pjField', '1', 'title', 'Email notifications will be sent to people who make a booking after the booking form is completed or/and payment is made. If you leave subject field blank no email will be sent. You can use tokens in the email messages to personalize them.<br /><br />\r\n\r\n<table width="100%" border="0" cellspacing="0" cellpadding="0">\r\n  <tbody><tr>\r\n    <td width="50%" valign="top"><p>{Name} - customer name;<br />\r\n      {Phone} - customer phone number; <br />\r\n      {Email} - customer e-mail address; <br />\r\n      {Notes} - additional notes; <br />\r\n      {Address1} - address 1; <br />\r\n      {Address2} - address 2; <br />\r\n      {City} - city; <br />\r\n      {State} - state; <br />\r\n      {Zip} - zip code; <br />\r\n      {Country} - country; <br />\r\n    </p></td>\r\n    <td width="50%" valign="top">\r\n	{BookingID} - Booking ID; <br />\r\n    {Services} - Selected services<br />\r\n    {CCType} - CC type; <br />\r\n      {CCNum} - CC number; <br />\r\n      {CCExpMonth} - CC exp.month; <br />\r\n      {CCExpYear} - CC exp.year; <br />\r\n      {CCSec} - CC sec. code; <br />\r\n      {PaymentMethod} - selected payment method; <br />\r\n      {Price} - price for selected services; <br />\r\n      {Deposit} - Deposit amount; <br />\r\n      {Tax} - Tax amount; <br />\r\n      {Total} - Total amount; <br />\r\n      {CancelURL} - Link for booking cancellation; </td>\r\n  </tr>\r\n</tbody></table>', 'script'),
('1380', '1357', 'pjField', '1', 'title', 'Enter booking terms and conditions. You can also include a link to external web page where your terms and conditions page is.', 'script'),
('1381', '1358', 'pjField', '1', 'title', 'Set different payment options for your Appointment Scheduler software. Enable or disable the available payment processing companies.', 'script'),
('1383', '1359', 'pjField', '1', 'title', 'Booking payment options', 'script'),
('1384', '1360', 'pjField', '1', 'title', 'Here you can set some general options about the booking process.', 'script'),
('1385', '1361', 'pjField', '1', 'title', 'Booking options', 'script'),
('1386', '1362', 'pjField', '1', 'title', 'Set-up general settings', 'script'),
('1387', '1363', 'pjField', '1', 'title', 'General options', 'script'),
('1388', '1364', 'pjField', '1', 'title', 'Hide prices', 'script'),
('1389', '1365', 'pjField', '1', 'title', 'Step (in minutes)', 'script'),
('1390', '1366', 'pjField', '1', 'title', 'Services', 'script'),
('1391', '1367', 'pjField', '1', 'title', 'Picture', 'script'),
('1398', '1368', 'pjField', '1', 'title', 'Delete picture', 'script'),
('1399', '1369', 'pjField', '1', 'title', 'Delete confirmation', 'script'),
('1400', '1370', 'pjField', '1', 'title', 'Are you sure you want to delete this picture?', 'script'),
('1409', '1371', 'pjField', '1', 'title', 'Install instructions', 'script'),
('1410', '1372', 'pjField', '1', 'title', 'In order to install this script into your web page, please follow below steps.', 'script'),
('1411', '1373', 'pjField', '1', 'title', 'Step 1 (Required)', 'script'),
('1412', '1374', 'pjField', '1', 'title', 'Step 2 (Optional) - for SEO purposes and better ranking you need to put next meta tag into the HEAD part of your page', 'script'),
('1413', '1375', 'pjField', '1', 'title', 'Step 3 (Optional) - for SEO purposes and better ranking you need to create a .htaccess file (or update existing one) with data below. Put the file in the same folder as your webpage.', 'script'),
('1421', '1376', 'pjField', '1', 'title', 'Use SEO URLs', 'script'),
('1429', '1377', 'pjField', '1', 'title', 'Time format', 'script'),
('1431', '1378', 'pjField', '1', 'title', 'Show week numbers', 'script'),
('1437', '1379', 'pjField', '1', 'title', 'Captcha', 'script'),
('1438', '1380', 'pjField', '1', 'title', 'Select Country', 'script'),
('1439', '1381', 'pjField', '1', 'title', 'I agree with terms and conditions', 'script'),
('1440', '1382', 'pjField', '1', 'title', 'Please go back to your basket.', 'script'),
('1441', '1383', 'pjField', '1', 'title', 'Select Payment method', 'script'),
('1442', '1384', 'pjField', '1', 'title', 'Select CC Type', 'script'),
('1449', '1385', 'pjField', '1', 'title', 'Employee', 'script'),
('1450', '1386', 'pjField', '1', 'title', 'Service', 'script'),
('1451', '1387', 'pjField', '1', 'title', 'From', 'script'),
('1452', '1388', 'pjField', '1', 'title', 'To', 'script'),
('1453', '1389', 'pjField', '1', 'title', 'Query', 'script'),
('1454', '1390', 'pjField', '1', 'title', 'Date', 'script'),
('1455', '1391', 'pjField', '1', 'title', 'Export selected', 'script'),
('1457', '1392', 'pjField', '1', 'title', 'Comma', 'script'),
('1458', '1393', 'pjField', '1', 'title', 'Semicolon', 'script'),
('1459', '1394', 'pjField', '1', 'title', 'Tab', 'script'),
('1460', '1395', 'pjField', '1', 'title', 'CSV', 'script'),
('1461', '1396', 'pjField', '1', 'title', 'XML', 'script'),
('1462', '1397', 'pjField', '1', 'title', 'iCal', 'script'),
('1463', '1398', 'pjField', '1', 'title', 'Delimiter', 'script'),
('1464', '1399', 'pjField', '1', 'title', 'Format', 'script'),
('1465', '1400', 'pjField', '1', 'title', 'Not Available', 'script'),
('1466', '1401', 'pjField', '1', 'title', 'Export Bookings', 'script'),
('1467', '1402', 'pjField', '1', 'title', 'Date/Time', 'script'),
('1469', '1403', 'pjField', '1', 'title', 'Service/Employee', 'script'),
('1470', '1404', 'pjField', '1', 'title', 'Reminder', 'script'),
('1471', '1405', 'pjField', '1', 'title', 'Check this if you want to send reminders to your clients.', 'script'),
('1472', '1406', 'pjField', '1', 'title', 'Set number of hours before the booking start time when an email reminder will be sent', 'script'),
('1473', '1407', 'pjField', '1', 'title', 'Email Reminder subject', 'script'),
('1474', '1408', 'pjField', '1', 'title', 'Set number of hours before the booking start time when an SMS reminder will be sent', 'script'),
('1477', '1410', 'pjField', '1', 'title', 'SMS message', 'script'),
('1478', '1411', 'pjField', '1', 'title', 'Email Reminder body', 'script'),
('1479', '1412', 'pjField', '1', 'title', 'Get key', 'script'),
('1480', '1413', 'pjField', '1', 'title', 'You can send email and sms reminders to your clients X hours before their booking. You can use these tokens to customize the messages that are sent.<br /><br />\r\n<table width="100%" border="0" cellspacing="0" cellpadding="0">\r\n  <tbody><tr>\r\n    <td width="50%" valign="top"><p>{Name} - customer name;<br />\r\n      {Phone} - customer phone number; <br />\r\n      {Email} - customer e-mail address;</p></td>\r\n    <td width="50%" valign="top">\r\n	{BookingID} - Booking ID; <br />\r\n    {Services} - Selected services<br />\r\n    {Price} - price for selected services; <br />\r\n      {Deposit} - Deposit amount; <br />\r\n      {Tax} - Tax amount; <br />\r\n      {Total} - Total amount; <br />\r\n      {CancelURL} - Link for booking cancellation; </td>\r\n  </tr>\r\n</tbody></table><br />\r\nYou should also set up a CRON job for cron.php file which should execute every hour. You need to use our SMS gateway to support sms reminders.', 'script'),
('1481', '1414', 'pjField', '1', 'title', 'Reminder options', 'script'),
('1482', '1415', 'pjField', '1', 'title', 'Booking updated', 'script'),
('1483', '1416', 'pjField', '1', 'title', 'All changes made to the booking has been saved.', 'script'),
('1484', '1417', 'pjField', '1', 'title', 'Booking not found', 'script'),
('1485', '1418', 'pjField', '1', 'title', 'Sorry, but the booking you''re looking for is missing.', 'script'),
('1486', '1419', 'pjField', '1', 'title', 'Booking added', 'script'),
('1487', '1420', 'pjField', '1', 'title', 'The booking has been successfully added.', 'script'),
('1488', '1421', 'pjField', '1', 'title', 'Booking not added', 'script'),
('1489', '1422', 'pjField', '1', 'title', 'Sorry, but the booking has not been added.', 'script'),
('1490', '1423', 'pjField', '1', 'title', 'Fill in the form below to add a new booking. Under Clients tab you can enter information about the client. ', 'script'),
('1491', '1424', 'pjField', '1', 'title', 'Add a booking', 'script'),
('1492', '1425', 'pjField', '1', 'title', 'Client details', 'script'),
('1493', '1426', 'pjField', '1', 'title', 'Use the form below to enter details about your client.', 'script'),
('1494', '1427', 'pjField', '1', 'title', 'Use form below to update client related data.', 'script'),
('1495', '1428', 'pjField', '1', 'title', 'Client details', 'script'),
('1496', '1429', 'pjField', '1', 'title', 'Use form below to update booking details.', 'script'),
('1497', '1430', 'pjField', '1', 'title', 'Booking update', 'script'),
('1504', '1431', 'pjField', '1', 'title', 'All the changes made to reminder have been saved.', 'script'),
('1505', '1432', 'pjField', '1', 'title', 'Reminder updated!', 'script'),
('1506', '1433', 'pjField', '1', 'title', 'All the changes made to terms have been saved.', 'script'),
('1507', '1434', 'pjField', '1', 'title', 'Terms updated!', 'script'),
('1508', '1435', 'pjField', '1', 'title', 'Confirmation updated!', 'script'),
('1509', '1436', 'pjField', '1', 'title', 'All the changes made to confirmation have been saved.', 'script'),
('1512', '1437', 'pjField', '1', 'title', 'All the changes made to booking form have been saved.', 'script'),
('1513', '1438', 'pjField', '1', 'title', 'Booking form updated!', 'script'),
('1514', '1439', 'pjField', '1', 'title', 'Payment options updated!', 'script'),
('1515', '1440', 'pjField', '1', 'title', 'All the changes made to payment options have been saved.', 'script'),
('1516', '1441', 'pjField', '1', 'title', 'All the changes made to booking options have been saved.', 'script'),
('1517', '1442', 'pjField', '1', 'title', 'Booking options updated!', 'script'),
('1531', '1454', 'pjField', '1', 'title', 'Recalculate the price', 'script'),
('1532', '1455', 'pjField', '1', 'title', '+ Add service', 'script'),
('1534', '1456', 'pjField', '1', 'title', 'Add service', 'script'),
('1535', '1457', 'pjField', '1', 'title', 'Delete confirmation', 'script'),
('1537', '1458', 'pjField', '1', 'title', 'Are you sure you want to delete selected service from the current booking?', 'script'),
('1538', '1459', 'pjField', '1', 'title', 'There are not any selected services yet.', 'script'),
('1539', '1460', 'pjField', '1', 'title', 'Total price', 'script'),
('1540', '1461', 'pjField', '1', 'title', 'Selected Services', 'script'),
('1541', '1462', 'pjField', '1', 'title', 'Select a Date', 'script'),
('1542', '1463', 'pjField', '1', 'title', 'Make an Appointment', 'script'),
('1543', '1464', 'pjField', '1', 'title', 'Start time', 'script'),
('1550', '1465', 'pjField', '1', 'title', 'End time', 'script'),
('1551', '1466', 'pjField', '1', 'title', 'Select service on', 'script'),
('1552', '1467', 'pjField', '1', 'title', 'Availability', 'script'),
('1553', '1468', 'pjField', '1', 'title', 'Booking Form', 'script'),
('1554', '1469', 'pjField', '1', 'title', 'System message', 'script'),
('1555', '1470', 'pjField', '1', 'title', 'Checkout form not available', 'script'),
('1556', '1471', 'pjField', '1', 'title', 'Return back', 'script'),
('1557', '1472', 'pjField', '1', 'title', 'Booking Preview', 'script'),
('1558', '1473', 'pjField', '1', 'title', 'Confirm booking', 'script'),
('1559', '1474', 'pjField', '1', 'title', 'Preview not available', 'script'),
('1561', '1475', 'pjField', '1', 'title', 'Invalid data', 'script'),
('1562', '1476', 'pjField', '1', 'title', 'Sorry, submitted data not validate.', 'script'),
('1563', '1477', 'pjField', '1', 'title', 'Profile', 'script'),
('1564', '1478', 'pjField', '1', 'title', 'Use form below to update your profile settings.', 'script'),
('1569', '1479', 'pjField', '1', 'title', 'IP address', 'script'),
('1570', '1480', 'pjField', '1', 'title', 'Booking Service details', 'script'),
('1571', '1481', 'pjField', '1', 'title', 'Send email', 'script'),
('1572', '1482', 'pjField', '1', 'title', 'Send SMS', 'script'),
('1573', '1483', 'pjField', '1', 'title', 'Subject', 'script'),
('1574', '1484', 'pjField', '1', 'title', 'Message', 'script'),
('1575', '1485', 'pjField', '1', 'title', 'Reports', 'script'),
('1576', '1486', 'pjField', '1', 'title', 'Employees', 'script'),
('1577', '1487', 'pjField', '1', 'title', 'Services', 'script'),
('1578', '1488', 'pjField', '1', 'title', 'Bookings', 'script'),
('1579', '1489', 'pjField', '1', 'title', 'All Bookings', 'script'),
('1580', '1490', 'pjField', '1', 'title', 'Confirmed Bookings', 'script'),
('1581', '1491', 'pjField', '1', 'title', 'Pending Bookings', 'script'),
('1582', '1492', 'pjField', '1', 'title', 'Cancelled Bookings', 'script'),
('1583', '1493', 'pjField', '1', 'title', 'Total amount', 'script'),
('1584', '1494', 'pjField', '1', 'title', 'Confirmed Bookings Amount', 'script'),
('1585', '1495', 'pjField', '1', 'title', 'Pending Bookings Amount', 'script'),
('1586', '1496', 'pjField', '1', 'title', 'Cancelled Bookings Amount', 'script'),
('1596', '1497', 'pjField', '1', 'title', 'Columns', 'script'),
('1597', '1498', 'pjField', '1', 'title', 'Print', 'script'),
('1598', '1499', 'pjField', '1', 'title', 'Save as PDF', 'script'),
('1600', '1500', 'pjField', '1', 'title', 'Menu', 'script'),
('1601', '1501', 'pjField', '1', 'title', 'View bookings', 'script'),
('1602', '1502', 'pjField', '1', 'title', 'Working time', 'script'),
('1603', '1503', 'pjField', '1', 'title', 'Services', 'script'),
('1604', '1504', 'pjField', '1', 'title', 'Below you can see the available services that your clients can book. Under Add service tab you can add a new service. Or use the edit icon for each service to modify it.', 'script'),
('1609', '1505', 'pjField', '1', 'title', 'Specify the time needed to do this service.', 'script'),
('1610', '1506', 'pjField', '1', 'title', 'In case you need some time before the start time for the service you can add it here. For example if your service is 60 minutes long and you input 30 minutes here, then when someone books a service at 10am you will not be available for other bookings between 9:30am and 10am', 'script'),
('1611', '1507', 'pjField', '1', 'title', 'In case you need some time after the end time for the service you can add it here. For example if your service is 60 minutes long and you input 30 minutes here, then when someone books a service at 10am till 11am you will not be available for other bookings between 11am and 11:30am', 'script'),
('1612', '1508', 'pjField', '1', 'title', 'Employees tooltip', 'script'),
('1623', '1509', 'pjField', '1', 'title', 'Send SMS when new booking is made', 'script'),
('1629', '1510', 'pjField', '1', 'title', 'Send to client', 'script'),
('1630', '1511', 'pjField', '1', 'title', 'Send to employee', 'script'),
('1633', '1512', 'pjField', '1', 'title', 'Click on available time to make an appointment', 'script'),
('1634', '1514', 'pjField', '1', 'title', 'Employees', 'script'),
('1635', '1515', 'pjField', '1', 'title', 'Below you can see a list of employees who do the different service you offer. You can have one or multiple employees.', 'script'),
('1652', '1530', 'pjField', '1', 'title', 'SEO', 'script'),
('1653', '1531', 'pjField', '1', 'title', 'Language options', 'script'),
('1654', '1532', 'pjField', '1', 'title', 'Language', 'script'),
('1655', '1533', 'pjField', '1', 'title', 'Hide language selector', 'script'),
('1656', '1534', 'pjField', '1', 'title', 'To better optimize your shopping cart please follow the steps below', 'script'),
('1657', '1535', 'pjField', '1', 'title', 'SEO Optimization', 'script'),
('1658', '1536', 'pjField', '1', 'title', 'Step 1. Webpage where your front end appointment scheduler is', 'script'),
('1659', '1537', 'pjField', '1', 'title', 'Step 2. Put the meta tag below between &lt;head&gt; and &lt;/head&gt; tags on your web page', 'script'),
('1660', '1538', 'pjField', '1', 'title', 'Step 3. Create .htaccess file (or update existing one) in the folder where your web page is and put the data below in it', 'script'),
('1661', '1539', 'pjField', '1', 'title', 'Generate', 'script'),
('1662', '1540', 'pjField', '1', 'title', 'Index', 'script'),
('1663', '1541', 'pjField', '1', 'title', 'Employees report', 'script'),
('1664', '1542', 'pjField', '1', 'title', 'Using the form below you can generate a report for specific service and date range. You can also generate the results based on number of services each employee did or the total amount paid for these services.', 'script'),
('1665', '1543', 'pjField', '1', 'title', 'Services report', 'script'),
('1666', '1544', 'pjField', '1', 'title', 'Using the form below you can generate a report for specific employee and date range. You can also generate the results based on number of services each employee did or the total amount paid for these services.', 'script'),
('1667', '1545', 'pjField', '1', 'title', 'Amount', 'script'),
('1668', '1546', 'pjField', '1', 'title', 'Count', 'script'),
('1669', '1547', 'pjField', '1', 'title', 'Below you can see working schedule for all employees. Using the date selector below to refresh the schedule. Click on Print button to print work timesheet.', 'script'),
('1670', '1548', 'pjField', '1', 'title', 'Dashboard', 'script'),
('1671', '1549', 'pjField', '1', 'title', 'Apply', 'script'),
('1672', '1550', 'pjField', '1', 'title', 'Dashboard filter', 'script'),
('1673', '1756', 'pjField', '1', 'title', 'Custom working time', 'script'),
('1674', '1758', 'pjField', '1', 'title', 'Using the form below you can set a custom working time for any date. Just select a date and set working time for it. Or you can just mark the date as a day off and bookings on that date will not be accepted. ', 'script'),
('1675', '1759', 'pjField', '1', 'title', 'Here you can set working time for this employee only. Different working time can be set for each day of the week. You can also set days off and a lunch break. ', 'script'),
('1676', '1760', 'pjField', '1', 'title', 'Working Time', 'script'),
('1677', '1761', 'pjField', '1', 'title', 'Custom working time', 'script'),
('1678', '1762', 'pjField', '1', 'title', 'Using the form below you can set a custom working time for any date for this employee only. Just select a date and set working time for it. Or you can just mark the date as a day off and bookings on that date for this employee will not be accepted.', 'script'),
('1679', '1768', 'pjField', '1', 'title', 'Today', 'script'),
('1680', '1769', 'pjField', '1', 'title', 'Tomorrow', 'script'),
('1681', '1770', 'pjField', '1', 'title', 'Dashboard Notice', 'script'),
('1682', '1771', 'pjField', '1', 'title', 'Selected date is set to "day off". Use the date picker above to choose another date. Please, note that you can change working time under Options page.', 'script'),
('1683', '1772', 'pjField', '1', 'title', 'Go to PayPal Secure page', 'script'),
('1684', '1773', 'pjField', '1', 'title', 'Go to Authorize.NET Secure page', 'script'),
('1685', '1774', 'pjField', '1', 'title', 'Please wait while redirect to secure payment processor webpage complete...', 'script'),
('1686', '1775', 'pjField', '1', 'title', 'Your request has been sent successfully. Thank you.', 'script'),
('1687', '1776', 'pjField', '1', 'title', 'Booking not found', 'script'),
('1688', '1777', 'pjField', '1', 'title', 'The invoice for this booking is already paid.', 'script'),
('1689', '1778', 'pjField', '1', 'title', 'Booking not available', 'script'),
('1690', '1779', 'pjField', '1', 'title', 'Start time', 'script'),
('1691', '1780', 'pjField', '1', 'title', 'End time', 'script'),
('1692', '1781', 'pjField', '1', 'title', 'Services not found', 'script'),
('1693', '1782', 'pjField', '1', 'title', 'You need to have at least a service.', 'script'),
('1694', '1783', 'pjField', '1', 'title', 'Employees not found', 'script'),
('1695', '1784', 'pjField', '1', 'title', 'You need to create employee and assign service first.', 'script'),
('1696', '1785', 'pjField', '1', 'title', 'mins', 'script'),
('1701', '1790', 'pjField', '1', 'title', 'on', 'script'),
('1702', '1791', 'pjField', '1', 'title', 'back to services', 'script'),
('1703', '1792', 'pjField', '1', 'title', 'Checkout', 'script'),
('1704', '1793', 'pjField', '1', 'title', 'Service added to your cart.', 'script'),
('1705', '1794', 'pjField', '1', 'title', 'Some of the items in your basket is not available.', 'script'),
('1706', '1795', 'pjField', '1', 'title', 'from', 'script'),
('1707', '1796', 'pjField', '1', 'title', 'till', 'script'),
('1708', '1797', 'pjField', '1', 'title', 'Missing, empty or invalid parameters.', 'script'),
('1709', '1798', 'pjField', '1', 'title', 'Booking with such an ID did not exists.', 'script'),
('1710', '1799', 'pjField', '1', 'title', 'Security hash did not match.', 'script'),
('1711', '1800', 'pjField', '1', 'title', 'Booking is already cancelled.', 'script'),
('1712', '1801', 'pjField', '1', 'title', 'Booking has been cancelled successfully.', 'script'),
('1713', '1802', 'pjField', '1', 'title', 'Customer Details', 'script'),
('1714', '1803', 'pjField', '1', 'title', 'Cancel booking', 'script'),
('1715', '1804', 'pjField', '1', 'title', 'Booking Services', 'script'),
('1716', '1805', 'pjField', '1', 'title', 'Booking Cancellation', 'script'),
('1717', '1806', 'pjField', '1', 'title', 'Employee - booking confirmation email', 'script'),
('1718', '1807', 'pjField', '1', 'title', 'Employee - payment confirmation email', 'script'),
('1719', '1808', 'pjField', '1', 'title', 'Update the default working time for all the employees', 'script'),
('1720', '1809', 'pjField', '1', 'title', 'Layout', 'script'),
('1721', '1810', 'pjField', '1', 'title', 'Select date', 'script'),
('1722', '1811', 'pjField', '1', 'title', 'Service', 'script'),
('1723', '1812', 'pjField', '1', 'title', 'Select time', 'script'),
('1724', '1813', 'pjField', '1', 'title', 'Employee', 'script'),
('1725', '1814', 'pjField', '1', 'title', 'Book', 'script'),
('1726', '1815', 'pjField', '1', 'title', 'Select date and service', 'script'),
('1727', '1816', 'pjField', '1', 'title', 'Choose date', 'script'),
('1728', '1817', 'pjField', '1', 'title', 'Date', 'script'),
('1729', '1818', 'pjField', '1', 'title', 'Price', 'script'),
('1730', '1819', 'pjField', '1', 'title', 'This invoice have been cancelled.', 'script'),
('1731', '1820', 'pjField', '1', 'title', 'not available on selected date and time', 'script'),
('1732', '1821', 'pjField', '1', 'title', 'Checkout', 'script'),
('1733', '1822', 'pjField', '1', 'title', 'Back to services', 'script'),
('1734', '1823', 'pjField', '1', 'title', 'View cart', 'script'),
('1735', '1824', 'pjField', '1', 'title', 'Invalid data', 'script'),
('1736', '1825', 'pjField', '1', 'title', 'Form data has not been saved. Please review data and try again.', 'script'),
('1737', '1826', 'pjField', '1', 'title', 'Read terms and conditions', 'script'),
('1738', '1827', 'pjField', '1', 'title', 'OK', 'script'),
('1739', '1828', 'pjField', '1', 'title', 'Terms and Conditions', 'script'),
('1740', '1829', 'pjField', '1', 'title', 'Tax', 'script'),
('1741', '1830', 'pjField', '1', 'title', 'Deposit payment', 'script'),
('1742', '1831', 'pjField', '1', 'title', 'Service(s) price', 'script'),
('3154', '2049', 'pjField', '1', 'title', 'Captcha is required', 'script'),
('3155', '2050', 'pjField', '1', 'title', 'Captcha is wrong', 'script'),
('3156', '2051', 'pjField', '1', 'title', 'You need to agree with the terms and conditions', 'script'),
('3157', '2052', 'pjField', '1', 'title', 'Notes is required', 'script'),
('3158', '2053', 'pjField', '1', 'title', 'Zip is required', 'script'),
('3159', '2054', 'pjField', '1', 'title', 'City is required', 'script'),
('3160', '2055', 'pjField', '1', 'title', 'State is required', 'script'),
('3161', '2056', 'pjField', '1', 'title', 'Country is required', 'script'),
('3162', '2058', 'pjField', '1', 'title', 'Address Line 1 is required', 'script'),
('3163', '2059', 'pjField', '1', 'title', 'Address Line 2 is required', 'script'),
('3164', '2060', 'pjField', '1', 'title', 'Phone is required', 'script'),
('3165', '2061', 'pjField', '1', 'title', 'Name is required', 'script'),
('3166', '2062', 'pjField', '1', 'title', 'Email is required', 'script'),
('3167', '2063', 'pjField', '1', 'title', 'Email is invalid', 'script'),
('3169', '2064', 'pjField', '1', 'title', 'Payment method is required', 'script'),
('3170', '2065', 'pjField', '1', 'title', 'CC Type is required', 'script'),
('3171', '2066', 'pjField', '1', 'title', 'CC Number is required', 'script'),
('3172', '2067', 'pjField', '1', 'title', 'CC Code is required', 'script'),
('3173', '2068', 'pjField', '1', 'title', 'This field is required.', 'script'),
('3175', '2069', 'pjField', '1', 'title', 'Please fix this field.', 'script'),
('3177', '2070', 'pjField', '1', 'title', 'Please enter a valid email address.', 'script'),
('3178', '2071', 'pjField', '1', 'title', 'Please enter a valid URL.', 'script'),
('3179', '2072', 'pjField', '1', 'title', 'Please enter a valid date.', 'script'),
('3180', '2073', 'pjField', '1', 'title', 'Please enter a valid date (ISO).', 'script'),
('3181', '2074', 'pjField', '1', 'title', 'Please enter a valid number.', 'script'),
('3182', '2075', 'pjField', '1', 'title', 'Please enter only digits.', 'script'),
('3183', '2076', 'pjField', '1', 'title', 'Please enter a valid credit card number.', 'script'),
('3184', '2077', 'pjField', '1', 'title', 'Please enter the same value again.', 'script'),
('3185', '2078', 'pjField', '1', 'title', 'Please enter no more than {0} characters.', 'script'),
('3186', '2079', 'pjField', '1', 'title', 'Please enter at least {0} characters.', 'script'),
('3187', '2080', 'pjField', '1', 'title', 'Please enter a value between {0} and {1} characters long.', 'script'),
('3188', '2081', 'pjField', '1', 'title', 'Please enter a value between {0} and {1}.', 'script'),
('3189', '2082', 'pjField', '1', 'title', 'Please enter a value less than or equal to {0}.', 'script'),
('3190', '2083', 'pjField', '1', 'title', 'Please enter a value greater than or equal to {0}.', 'script'),
('3191', '2084', 'pjField', '1', 'title', 'Please enter a value with a valid extension.', 'script'),
('3235', '2085', 'pjField', '1', 'title', 'st', 'script'),
('3236', '2086', 'pjField', '1', 'title', 'nd', 'script'),
('3237', '2087', 'pjField', '1', 'title', 'rd', 'script'),
('3238', '2088', 'pjField', '1', 'title', 'th', 'script'),
('3239', '2089', 'pjField', '1', 'title', 'th', 'script'),
('3240', '2090', 'pjField', '1', 'title', 'th', 'script'),
('3241', '2091', 'pjField', '1', 'title', 'th', 'script'),
('3242', '2092', 'pjField', '1', 'title', 'th', 'script'),
('3243', '2093', 'pjField', '1', 'title', 'th', 'script'),
('3244', '2094', 'pjField', '1', 'title', 'th', 'script'),
('3245', '2095', 'pjField', '1', 'title', 'th', 'script'),
('3246', '2096', 'pjField', '1', 'title', 'th', 'script'),
('3247', '2097', 'pjField', '1', 'title', 'th', 'script'),
('3248', '2098', 'pjField', '1', 'title', 'th', 'script'),
('3249', '2099', 'pjField', '1', 'title', 'th', 'script'),
('3250', '2100', 'pjField', '1', 'title', 'th', 'script'),
('3251', '2101', 'pjField', '1', 'title', 'th', 'script'),
('3252', '2102', 'pjField', '1', 'title', 'th', 'script'),
('3253', '2103', 'pjField', '1', 'title', 'th', 'script'),
('3254', '2104', 'pjField', '1', 'title', 'th', 'script'),
('3255', '2105', 'pjField', '1', 'title', 'st', 'script'),
('3256', '2106', 'pjField', '1', 'title', 'nd', 'script'),
('3258', '2107', 'pjField', '1', 'title', 'rd', 'script'),
('3259', '2108', 'pjField', '1', 'title', 'th', 'script'),
('3260', '2109', 'pjField', '1', 'title', 'th', 'script'),
('3261', '2110', 'pjField', '1', 'title', 'th', 'script'),
('3262', '2111', 'pjField', '1', 'title', 'th', 'script'),
('3263', '2112', 'pjField', '1', 'title', 'th', 'script'),
('3264', '2113', 'pjField', '1', 'title', 'th', 'script'),
('3265', '2114', 'pjField', '1', 'title', 'th', 'script'),
('3266', '2115', 'pjField', '1', 'title', 'st', 'script'),
('3280', '2116', 'pjField', '1', 'title', 'N/A', 'script'),
('3283', '2117', 'pjField', '1', 'title', 'N/A', 'script'),
('3297', '2118', 'pjField', '1', 'title', 'Check all', 'script'),
('3298', '2119', 'pjField', '1', 'title', 'Uncheck all', 'script'),
('3299', '2120', 'pjField', '1', 'title', 'Select options', 'script'),
('3300', '2121', 'pjField', '1', 'title', 'selected', 'script'),
('3305', '2122', 'pjField', '1', 'title', 'Client - booking cancellation email', 'script'),
('3306', '2123', 'pjField', '1', 'title', 'Employee - booking cancellation email', 'script'),
('3307', '2124', 'pjField', '1', 'title', 'Admin - booking cancellation email', 'script'),
('4821', '2374', 'pjField', '1', 'title', 'Service has been added to your cart.', 'script'),
('4822', '2375', 'pjField', '1', 'title', 'Missing, empty or invalid parameters.', 'script'),
('4823', '2376', 'pjField', '1', 'title', 'Service has been removed from your cart.', 'script'),
('4824', '2377', 'pjField', '1', 'title', 'Missing, empty or invalid parameters.', 'script'),
('4825', '2378', 'pjField', '1', 'title', 'Checkout data is missing (or not valid form submit).', 'script'),
('4826', '2379', 'pjField', '1', 'title', 'Captcha doesn''t match.', 'script'),
('4827', '2380', 'pjField', '1', 'title', 'Cart is empty or invalid services.', 'script'),
('4828', '2381', 'pjField', '1', 'title', 'Booking data is not valid.', 'script'),
('4829', '2382', 'pjField', '1', 'title', 'Booking failed.', 'script'),
('4830', '2383', 'pjField', '1', 'title', 'Checkout form has been saved.', 'script'),
('4831', '2384', 'pjField', '1', 'title', 'Some of the services in your cart are not available.', 'script'),
('4834', '2385', 'pjField', '1', 'title', 'Booking has been successful.', 'script');

-- Do not remove below

INSERT INTO `appscheduler_multi_lang` VALUES
(NULL, '1', 'pjCalendar', '1', 'confirm_subject_client', 'Booking confirmation', 'data'),
(NULL, '1', 'pjCalendar', '1', 'confirm_tokens_client', 'Thank you for your booking. \r\n\r\nID: {BookingID}\r\n\r\nServices\r\n{Services}\r\n\r\nPersonal details\r\nName: {Name}\r\nPhone: {Phone}\r\nEmail: {Email}\r\n\r\nThis is the price for your booking\r\nTax: {Price}\r\nTax: {Tax}\r\nTotal: {Total}\r\nDeposit required to confirm your booking: {Deposit}\r\n\r\nAdditional notes:\r\n{Notes}\r\n\r\nThank you,\r\nThe Management', 'data'),
(NULL, '1', 'pjCalendar', '1', 'payment_subject_client', 'Payment received', 'data'),
(NULL, '1', 'pjCalendar', '1', 'payment_tokens_client', 'We''ve received the payment for your booking and it is now confirmed.\r\n\r\nID: {BookingID}\r\n\r\nThank you,\r\nThe Management', 'data'),
(NULL, '1', 'pjCalendar', '1', 'confirm_subject_admin', 'New booking received', 'data'),
(NULL, '1', 'pjCalendar', '1', 'confirm_tokens_admin', 'New booking has been made. \r\n\r\nID: {BookingID}\r\n\r\nServices\r\n{Services}\r\n\r\nPersonal details\r\nName: {Name}\r\nPhone: {Phone}\r\nEmail: {Email}\r\n\r\nPrice\r\nTax: {Price}\r\nTax: {Tax}\r\nTotal: {Total}\r\nDeposit required to confirm the booking: {Deposit}\r\n\r\nAdditional notes:\r\n{Notes}', 'data'),
(NULL, '1', 'pjCalendar', '1', 'payment_subject_admin', 'New payment received', 'data'),
(NULL, '1', 'pjCalendar', '1', 'payment_tokens_admin', 'Booking deposit has been paid.\r\n\r\nID: {BookingID}', 'data'),
(NULL, '1', 'pjCalendar', '1', 'confirm_subject_employee', 'New appointment received', 'data'),
(NULL, '1', 'pjCalendar', '1', 'confirm_tokens_employee', 'New appointment has been made.\r\n\r\nID: {BookingID}\r\n\r\nServices\r\n{Services}\r\n\r\nPersonal details\r\nName: {Name}\r\nPhone: {Phone}\r\nEmail: {Email}\r\n\r\nAdditional notes:\r\n{Notes}', 'data'),
(NULL, '1', 'pjCalendar', '1', 'payment_subject_employee', 'New payment received', 'data'),
(NULL, '1', 'pjCalendar', '1', 'payment_tokens_employee', 'Booking deposit has been paid.\r\n\r\nID: {BookingID}', 'data'),
(NULL, '1', 'pjCalendar', '1', 'cancel_subject_client', 'Boooking cancellation', 'data'),
(NULL, '1', 'pjCalendar', '1', 'cancel_tokens_client', 'Your booking has been cancelled.\r\n\r\nID: {BookingID}\r\n\r\nThank you,\r\nThe Management', 'data'),
(NULL, '1', 'pjCalendar', '1', 'cancel_subject_admin', 'Booking cancelled', 'data'),
(NULL, '1', 'pjCalendar', '1', 'cancel_tokens_admin', 'Booking has been cancelled.\r\n\r\nID: {BookingID}', 'data'),
(NULL, '1', 'pjCalendar', '1', 'cancel_subject_employee', 'Booking cancelled', 'data'),
(NULL, '1', 'pjCalendar', '1', 'cancel_tokens_employee', 'Booking has been cancelled.\r\n\r\nID: {BookingID}', 'data');